/********************************************************************\

  Name:         dastemp.c(pp)
  Created by:   Stefan Ritt

  Contents:     Slowcontrol module for Keithley DAS-TEMP

  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  26-APR-96    SR    created


\********************************************************************/

#include <stdio.h>
#include <conio.h>
#include <math.h>
#include "midas.h"

/**** define board base address, has to mach jumper setting *********/

static unsigned short io_base = 0x220; // default value

#define MAX_CHAN_TEMP 32

/*------------------------------------------------------------------*/

#define CT0     (unsigned short) (io_base+0x00)
#define CT1     (unsigned short) (io_base+0x01)
#define CT2     (unsigned short) (io_base+0x02)
#define CTC     (unsigned short) (io_base+0x03)
#define STATUS  (unsigned short) (io_base+0x04)
#define INTR    (unsigned short) (io_base+0x05)
#define LCZS    (unsigned short) (io_base+0x06)

/*------------------------------------------------------------------*/

double dastemp_read_channel(int channel)
{
unsigned short int data;
double             temp;

  /* set up counter 1 for gating */
  _outp(CTC, 0x72); // HW one shot
  _outp(CT1, 0x40); // 0x9C40 for 50 Hz rej.
  _outp(CT1, 0x9C);

  /* set up counter 0 for V-F counting */
  _outp(CTC, 0x30); // event counting mode for cntr0
  _outp(CT0, 0xFF); // 0xFFFF
  _outp(CT0, 0xFF);
  _outp(LCZS, 0);   // load cntr0

  /* select channel */
  _outp(STATUS, (channel & 31) | 0x80);

  /* trigger a conversion */
  data = _inp(CTC);

  /* wait until "dummy" conversion is ready */
  do
    {
    data = _inp(STATUS);
    } while (data & (1<<5));

  /* set up counter 0 for V-F counting */
  _outp(CTC, 0x30); // event counting mode for cntr0
  _outp(CT0, 0xFF); // 0xFFFF
  _outp(CT0, 0xFF);
  _outp(LCZS, 0);   // load cntr0

  /* trigger a conversion */
  data = _inp(CTC);

  /* wait until "real" conversion is ready */
  do
    {
    data = _inp(STATUS);
    } while (data & (1<<5));

  /* latch counter command */
  _outp(CTC, 0x00);

  /* read data */
  data = _inp(CT0);
  data |= (_inp(CT0) << 8);
  data = 65535 - data;

  temp = data * 0.0125 - 273.15;

  /* round temperature to 0.01 deg */
  temp = ((int) (temp*100 +0.5))/100.0;

  return temp ;
}

