/********************************************************************\

  Name:         anasys.c
  Created by:   Stefan Ritt

  Contents:     PiBeta System part of Analyzer code


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  16-DEC-96    SR    created


\********************************************************************/
                                                        
/* standard includes */
#include <stdio.h>

/* midas includes */
#include "midas.h"
#include "..\event.h"

/* cernlib includes */
#define VISUAL_CPLUSPLUS
#include <cfortran.h>
#include <hbook.h>

/*-- Globals -------------------------------------------------------*/

/* The analyzer name (client name) as seen by other MIDAS clients   */
char *analyzer_name = "Remote";

/* analyzer_loop is called with this interval in ms (0 to disable)  */
INT  analyzer_loop_period = 0;

extern HNDLE hDB;

/* ODB structures */
RUNINFO   runinfo;
ANA_PARAM ana_param;
EXP_PARAM exp_param;

/*-- Function declarations -----------------------------------------*/

extern INT  analyze_trigger_event(EVENT_HEADER*);
extern INT  analyze_scaler_event(EVENT_HEADER*);
extern INT  ana_init();

/*-- Event request list --------------------------------------------*/

ANALYZE_REQUEST analyze_request[] = {

  { "Trigger",            /* event name */
    1,                    /* event ID */
    TRIGGER_ALL,          /* trigger mask */
    GET_SOME,             /* get some events */
    "SYSTEM",             /* event buffer */
    TRUE,                 /* enabled */
    "", "", 
    analyze_trigger_event,/* analyzer routine */
  },

  { "Scaler",             /* equipment name */
    2,                    /* event ID */
    TRIGGER_ALL,          /* trigger mask */
    GET_ALL,              /* get all events */
    "SYSTEM",             /* event buffer */
    TRUE,                 /* enabled */
    "", "", 
    analyze_scaler_event  /* analyzer routine */
  },

  { "" }
};

/*-- Analyzer Init -------------------------------------------------*/

INT analyzer_init()
{
HNDLE hKey;

  /* open ODB structures */

  if (db_find_key(hDB, 0, "/Runinfo", &hKey) != DB_SUCCESS)
    cm_msg(MERROR, "Cannot find \"/Runinfo\" tree in ODB");
  else
    if (db_open_record(hDB, hKey, &runinfo, sizeof(runinfo), MODE_READ, NULL) != DB_SUCCESS)
      goto error;

  if (db_find_key(hDB, 0, "/Analyzer/Parameters", &hKey) != DB_SUCCESS)
    cm_msg(MERROR, "Cannot find \"/Analyzer/Parameters\" tree in ODB");
  else
    if (db_open_record(hDB, hKey, &ana_param, sizeof(ana_param), MODE_READ, NULL) != DB_SUCCESS)
      goto error;

  if (db_find_key(hDB, 0, "/Experiment/Run Parameters", &hKey) != DB_SUCCESS)
    cm_msg(MERROR, "Cannot find \"/Experiment/Run Parameters\" tree in ODB");
  else
    if (db_open_record(hDB, hKey, &exp_param, sizeof(exp_param), MODE_READ, NULL) != DB_SUCCESS)
      goto error;

  /* call user init function */  
  return ana_init();

error:
  printf("\nEvent structures have been changed in ODB, please recompile analyzer.\n");
  return 0;
}

/*-- Analyzer Exit -------------------------------------------------*/

INT analyzer_exit()
{
  return CM_SUCCESS;
}

/*-- Pause Run -----------------------------------------------------*/

INT ana_pause_run(INT run_number, char *error)
{
  return CM_SUCCESS;
}

/*-- Resuem Run ----------------------------------------------------*/

INT ana_resume_run(INT run_number, char *error)
{
  return CM_SUCCESS;
}

/*-- Analyzer Loop -------------------------------------------------*/

INT analyzer_loop()
{
  return CM_SUCCESS;
}

/*------------------------------------------------------------------*/

void get_hbook_filename(char *path)
{
int  flag, size, run_number;
char dir[256];
char filename[256];

  /* get dump flag */
  cm_get_experiment_database(&hDB, NULL);
  size = sizeof(flag);
  flag = TRUE;
  db_get_value(hDB, 0, "/Analyzer/Histo dump", &flag, &size, TID_BOOL);
  if (flag)
    {
    size = sizeof(dir);
    dir[0] = 0;
    db_get_value(hDB, 0, "/logger/data dir", dir, &size, TID_STRING);
    if (dir[0] != 0)
      if (dir[strlen(dir)-1] != DIR_SEPARATOR)
        strcat(dir, DIR_SEPARATOR_STR);
    strcpy(path, dir);
      
    filename[0] = 0;
    db_get_value(hDB, 0, "/Analyzer/Histo dump file", filename, &size, TID_STRING);
    if (filename[0] == 0)
      strcpy(filename, "run*.hbook");

    if (strchr(filename, '*'))
      {
      size = sizeof(run_number);
      db_get_value(hDB, 0, "/runinfo/run number", &run_number, &size, TID_INT);
      strcat(path, filename);
      sprintf(strchr(path, '*'), "%04d", run_number);
      strcat(path, strchr(filename, '*')+1);
      }
    else
      strcat(path, filename);
    }
  else
    path[0] = 0;
}

/*-- Book N-tuples from tag list -----------------------------------*/

/* tag structure */
typedef struct {
  char name[8];
  int  n;
} TAG;

INT book_nt(INT id, char *nt_name, INT n_tag, TAG *taglist, INT n_buffer)
{
char name[NAME_LENGTH];
int  i, j, k;
char tags[1000][8];

  /* generate tags for calculated values */
  for (i=0,j=0 ; taglist[i].name[0] ; i++)
    {
    if (taglist[i].n == 1)
      {
      /* single tags */
      if (strlen(taglist[i].name) > 7)
        printf("WARNING: Tag %s too long\n", taglist[i].name);
      memcpy(tags[j++], taglist[i].name, 8);
      }
    else
      {
      /* tag array */
      for (k=0 ; k<taglist[i].n ; k++)
        {
        sprintf(name, "%s%d", taglist[i].name, k);
        if (strlen(name) > 8)
          printf("WARNING: Tag %s too long\n", name);
        memcpy(tags[j++], name, 8);
        }
      }
    if (j > n_tag)
      {
      printf("ERROR: calc structure doesn't match tags");
      return 0;
      }
    if (j*8 >= sizeof(tags))
      {
      printf("ERROR: tags array too small, please increase");
      return 0;
      }
    }
  if (j != n_tag)
    {
    printf("ERROR: calc structure doesn't match tags");
    return 0;
    }

  /* book calculated values N-tuple */
  HBOOKN(id, nt_name, n_tag, " ", n_tag*n_buffer, tags);
}
