/********************************************************************\

  Name:         scope.c
  Created by:   Stefan Ritt

  Contents:     Waveform readout of Tektronix TDS 620 oscilloscope


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  19-MAR-97    SR    created


\********************************************************************/
                                                        
/*-- Include files -------------------------------------------------*/
#include <windows.h>
#include <stdio.h>
#include <math.h>
#include "decl-32.h"

/*-- GPIB Address  -------------------------------------------------*/
#define TDS620_ADDR 1

/*------------------------------------------------------------------*/

int main()
{
int      hdev, offset, n, i;
char     str[80];
unsigned char   data[10000];
FILE     *f;
double   x_scale, y_scale, y_offset;

  /* initialization */
 
  hdev = ibdev(0, TDS620_ADDR, 0, T3s, 1, 0);
  if (hdev < 0)
    {
    printf("GPIB error");
    return 0;
    }
  ibclr(hdev);
  if (ibsta & ERR) 
    {
    printf("Error: scope off or cable not connected");
    return 0;
    }

  ibwrt(hdev,"ID?", 3);
  if (ibsta & ERR) 
    {
    printf("Error: scope not initialized");
    return 0;
    }

  ibrd(hdev, str, sizeof(str));
  if (ibsta & ERR) 
    {
    printf("ibrd Error");
    return 0;
    }
  str[ibcnt] = '\0';

  /* calculate X scale */
  ibwrt(hdev, "HOR:MAI:SCA?", 12);
  ibrd(hdev, str, sizeof(str));
  str[ibcnt] = 0;
  sscanf(str, "%lf", &x_scale);
  x_scale = x_scale * 10 / 500.0;

  /* calculate Y scale */
  ibwrt(hdev, "CH1:SCALE?", 10);
  ibrd(hdev, str, sizeof(str));
  str[ibcnt] = 0;
  sscanf(str, "%lf", &y_scale);

  /* calculate Y offset */
  ibwrt(hdev, "CH1:POSITION?", 13);
  ibrd(hdev, str, sizeof(str));
  str[ibcnt] = 0;
  sscanf(str, "%lf", &y_offset);
  y_offset = y_offset * y_scale;
  y_scale = y_scale * 10 / 256.0;

  /* request curve */
  ibwrt(hdev, "CURVE?", 6);
  ibrd(hdev, data, sizeof(data));
  if (ibsta & ERR) 
    {
    printf("ibrd Error");
    return 0;
    }

  /* calculate curve length from header */
  n = 0;
  for (i = 2 ; i<2+data[1]-'0' ; i++)
    n = n*10 + data[i] - '0';

  offset = data[1] - '0' + 2;

  /* open destination file */
  f = fopen("scope.wav", "w");
  if (f == NULL)
    {
    printf("cannot open file");
    return 0;
    }

  /* write data */
  fprintf(f, "t[s] y[Volt]\n");
  for (i=0;i<n;i++)
    fprintf(f, "%lg %lg\n", x_scale*i, y_scale*(data[i+offset]-128)-y_offset);
  fclose(f);

  printf("Waveform written successfully to \"scope.wav\"\n");

  /* exit GPIB */
  ibonl(hdev, 0);

  return 1;
}

