#include <windows.h>
#include <stdio.h>
#include <conio.h>

/*------------------------------------------------------------------*/

static HANDLE _hdio = 0;

INT ss_directio_init()
{
  _hdio = CreateFile("\\\\.\\directio", GENERIC_READ, FILE_SHARE_READ, NULL,
			               OPEN_EXISTING, 0, NULL);
  if (_hdio == INVALID_HANDLE_VALUE)
    return -1;

  return 0;
}

/*------------------------------------------------------------------*/

INT ss_directio_exit()
{
  return CloseHandle(_hdio);
}

/*------------------------------------------------------------------*/

INT ss_directio_give_port(INT start, INT end)
{
DWORD buffer[] = {6, start, end, 0};
DWORD size;

  if (_hdio <= 0)
    return -1;

  if (DeviceIoControl(_hdio, (DWORD) 0x9c406000, &buffer, sizeof(buffer), 
                      NULL, 0, &size, NULL))
    return 0;

  return GetLastError();
}

/*------------------------------------------------------------------*/

/**** define board base address, has to mach jumper setting *********/

static unsigned short io_base = 0x220; // default value

#define MAX_CHAN_TEMP 32

/*------------------------------------------------------------------*/

#define CT0     (unsigned short) (io_base+0x00)
#define CT1     (unsigned short) (io_base+0x01)
#define CT2     (unsigned short) (io_base+0x02)
#define CTC     (unsigned short) (io_base+0x03)
#define STATUS  (unsigned short) (io_base+0x04)
#define INTR    (unsigned short) (io_base+0x05)
#define LCZS    (unsigned short) (io_base+0x06)

/*------------------------------------------------------------------*/

double dastemp_read_channel(int channel)
{
unsigned short int data;
double             temp;

  /* set up counter 1 for gating */
  _outp(CTC, 0x72); // HW one shot
  _outp(CT1, 0x40); // 0x9C40 for 50 Hz rej.
  _outp(CT1, 0x9C);

  /* set up counter 0 for V-F counting */
  _outp(CTC, 0x30); // event counting mode for cntr0
  _outp(CT0, 0xFF); // 0xFFFF
  _outp(CT0, 0xFF);
  _outp(LCZS, 0);   // load cntr0

  /* select channel */
  _outp(STATUS, (channel & 31) | 0x80);

  /* trigger a conversion */
  data = _inp(CTC);

  /* wait until "dummy" conversion is ready */
  do
    {
    data = _inp(STATUS);
    } while (data & (1<<5));

  /* set up counter 0 for V-F counting */
  _outp(CTC, 0x30); // event counting mode for cntr0
  _outp(CT0, 0xFF); // 0xFFFF
  _outp(CT0, 0xFF);
  _outp(LCZS, 0);   // load cntr0

  /* trigger a conversion */
  data = _inp(CTC);

  /* wait until "real" conversion is ready */
  do
    {
    data = _inp(STATUS);
    } while (data & (1<<5));

  /* latch counter command */
  _outp(CTC, 0x00);

  /* read data */
  data = _inp(CT0);
  data |= (_inp(CT0) << 8);
  data = 65535 - data;

  temp = data * 0.0125 - 273.15;

  /* round temperature to 0.01 deg */
  temp = ((int) (temp*100 +0.5))/100.0;

  return temp ;
}

/*------------------------------------------------------------------*/

main()
{
double t;
int i;

  ss_directio_init();
  ss_directio_give_port(0x220, 0x22F);
  ss_directio_exit();

  for (i=0 ; i<32 ; i++)
    {
    t = dastemp_read_channel(i);

    printf("%02d:%7.2lf         ", i, t);
    if (i%4 == 3)
      printf("\n");
    }

  return 0;
}