/* IEEE support */
#include "ieee-c.h"

/**** Tektronix TDS 620 **************************************************/

#define SC_ADDR 1

int init_scope(void)
/************************************************
* Initialize GPIB and test for scope response   *
* The Scope address is 1                        *
* See Tek Programmer Manual p. 1-6              *
*************************************************/
{
int status;

  /* check if IEEE-488 board is present */
  if (!gpib_board_present())
    {
    printf("No board installed !");
    return(-1);
    }

  /* init IEEE-488 board */
  initialize (21,0);

  /* check TDS GPIB address */
  send(SC_ADDR,"ID?",&status);
  if (status != 0)
    {
    printf("scope is not responding");
    return(-1);
    }

  printf("Initializing scope...");

  /* Recall factory settings */
  send(SC_ADDR, "FACTORY",  &status);

  /* set correct scope parameters */
  send(SC_ADDR, "TRIG:MAI:EDGE:SOUR CH1", &status);   // trigger source
  send(SC_ADDR, "TRIG:MAI:EDGE:SLOPE FALL", &status); // falling slope
  send(SC_ADDR, "TRIG:MAI:LEV -0.1", &status);        // -100 mV

  send(SC_ADDR, "HOR:MODE MAIN", &status);            // Time Base Main
  send(SC_ADDR, "HOR:MAI:SCA 100E-9", &status);       // 100ns/DIV
  send(SC_ADDR, "HOR:RECO 1000", &status);            // 1000 points
  send(SC_ADDR, "HOR:POS 35", &status);               // Hor. pos. 35%
  send(SC_ADDR, "HOR:TRIG:POS 20", &status);          // Trig. pos. 20%

  send(SC_ADDR, "CH1:BAND FULL", &status);            // Full bandwidth
  send(SC_ADDR, "CH1:COUP DC", &status);              // DC coupling
  send(SC_ADDR, "CH1:IMP FIFTY", &status);            // 50 Ohm
  send(SC_ADDR, "CH1:OFFSET 0", &status);             // Offset 0V
  send(SC_ADDR, "CH1:POSITION 3", &status);           // Vert. pos. 3DIV
  send(SC_ADDR, "CH1:SCALE 100E-3", &status);         // 100mV / DIV

//  send(SC_ADDR, "CH4:COUP DC", &status);              // used as trigger?
//  send(SC_ADDR, "CH4:IMP FIF", &status);
//  send(SC_ADDR, "CH4:SCALE 500E-3", &status);

  /* turn on cursor to show short gate */
  send(SC_ADDR, "CURSOR:FUNC VBARS", &status);        // Vertical cursors
  send(SC_ADDR, "CURSOR:VBARS:UNITS SECONDS", &status);
  send(SC_ADDR, "CURSOR:VBARS:POSITION1 -15.0E-9", &status);
  send(SC_ADDR, "CURSOR:VBARS:POSITION2 85.0E-9", &status);

  /* send acquisition mode and waveform specifications*/
  send(SC_ADDR, "ACQ:MODE SAMPLE", &status);
  send(SC_ADDR, "ACQ:STOPA SEQ", &status);

  send(SC_ADDR, "DAT:SOURCE CH1",  &status);          // Source: Channel 1
  send(SC_ADDR, "DAT:ENC RPB",     &status);          // Binary encoding
  send(SC_ADDR, "DAT:WIDTH 1",     &status);          // 1 byte values
  send(SC_ADDR, "DAT:START 1",     &status);          // points 1..1000
  send(SC_ADDR, "DAT:STOP 1000",   &status);

  send(SC_ADDR, "HEADER OFF",      &status);          // No header in queries

  /* Misc. */
  send(SC_ADDR, "CLEARMENU", &status);                // Clear menu
//  send(SC_ADDR, "LOCK ALL", &status);                 // Lock front panel
  send(SC_ADDR, "BELL", &status);                     // Ring bell

  printf("done\n");

  return(1);
}

int rearm(void)
{
int status;

  /* acquire waveform data  */
  send(SC_ADDR, "ACQ:STATE ON", &status);
  if (status != 0)
    printf("Rearm failed!\n");

  return(1);
}

int read_scope()
{
int           i, status, length, offset;
unsigned char data[1100];
char          recv[50];

  send(SC_ADDR, "TRIG:STATE?", &status);
  enter(recv, 50, &length, SC_ADDR, &status);
  if (status != 0)
    printf("Trigger state readout failed!\n");

  if (recv[0] == 'S')
    {
    send(1, "CURVE?", &status);
    enter(data, 1100, &length, SC_ADDR, &status);
    if (status != 0)
      printf("Waveform readout failed!\n");

    offset = data[1] - '0' + 2;
    for (i=0;i<1000;i++)
      irq_event->waveform[i] = data[i+offset];

    rearm();
    return 1;
    }

  return 0;
}
