/********************************************************************\

  Name:         angle2.c
  Created by:   Penny Slocum

  Contents:     PiBeta Analyzer module for calculation of reconstructed
                hit points for CsI.


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  5-JUL-97     PS    created

\********************************************************************/
                                                        
/*-- Include files -------------------------------------------------*/

/* standard includes */
#include <stdio.h>
#include <math.h>

/* midas includes */
#include "midas.h"
#include "hardware.h"
#include "event.h"
#include "analyzer.h"

/*-- Parameters ----------------------------------------------------*/

extern GLOBAL_PARAM global_param;
extern EXP_PARAM exp_param;
extern ANGLE2_PARAM angle2_param;
ANGLE2_PARAM angle2_param;

extern double csi_theta[240];
extern double csi_phi[240];

/*-- Static parameters ---------------------------------------------*/

#ifndef sqr
#define sqr(x) ((x)*(x))
#endif
#ifndef PI
#define PI 3.14159265359
#endif

double out_mat2[3][3]; /* calculated in BOR routine */

int csi_index[] = {
  115, 164, 191, 124,  74, 120, 168, 195, 129,  15,  /*  0: 9 */
   65, 170,  73,  24,  20,  70, 174,  78,  29,  16,  /* 10:19 */
  116, 123,  23,   2,  21, 121, 128,  28,  66, 165,  /* 20:29 */ 
   72,  22,  71, 169,  77, 203, 204, 122, 205, 206,  /* 30:39 */
  223, 224, 225, 226 };                              /* 40:43 */

double nai_x[N_NAI] = {
  -2.5, -1.5, -0.5,  0.5,  1.5,  2.5,
  -2.5, -1.5, -0.5,  0.5,  1.5,  2.5,
  -2.5, -1.5, -0.5,  0.5,  1.5,  2.5,
  -2.5, -1.5, -0.5,  0.5,  1.5,  2.5,
  -2.5, -1.5, -0.5,  0.5,  1.5,  2.5,
  -2.5, -1.5, -0.5,  0.5,  1.5,  2.5,
  -3.5, -2.5, -1.5, -0.5,  0.5,  1.5,  2.5,  3.5,
  -3.5, 3.5,
  -3.5, 3.5,
  -3.5, 3.5,
  -3.5, 3.5,
  -3.5, 3.5,
  -3.5, 3.5,
  -3.5, -2.5, -1.5, -0.5,  0.5,  1.5,  2.5,  3.5,
};

double nai_y[N_NAI] = {
   2.5,  2.5,  2.5,  2.5,  2.5,  2.5,
   1.5,  1.5,  1.5,  1.5,  1.5,  1.5,
   0.5,  0.5,  0.5,  0.5,  0.5,  0.5,
  -0.5, -0.5, -0.5, -0.5, -0.5, -0.5,
  -1.5, -1.5, -1.5, -1.5, -1.5, -1.5,
  -2.5, -2.5, -2.5, -2.5, -2.5, -2.5,
   3.5,  3.5,  3.5,  3.5,  3.5,  3.5,  3.5,  3.5,
   2.5,  2.5,
   1.5,  1.5,
   0.5,  0.5,
  -0.5, -0.5,
  -1.5, -1.5,
  -2.5, -2.5,
  -3.5, -3.5, -3.5, -3.5, -3.5, -3.5, -3.5, -3.5,
};

/* NaI angles in Penny's CsI coordinate system */
double nai_phi[] = {
/* inner crystals */
316.12, 330.02, 349.11, 10.89, 29.98, 43.88,
302.62, 316.85, 342.65, 17.35, 43.15, 57.38,
283.50, 291.80, 320.19, 39.81, 68.20, 76.50,
260.91, 255.07, 231.34, 128.66, 104.93, 99.09,
240.75, 226.97, 199.65, 160.35, 133.03, 119.25,
226.17, 212.01, 191.77, 11.07, 12.73, 15.47,

/* outer crystals */
315.81, 325.22, 337.38, 352.09, 7.91, 22.62, 34.78, 44.19, 
306.61, 53.39,
294.57, 65.43,
279.73, 80.27,
263.48, 96.52,
248.20, 111.80,
235.56, 124.44,
225.83, 216.33, 203.81, 188.37, 171.63, 156.19, 143.67, 134.17
};

double nai_theta[] = {
/* inner crystals */
16.07, 13.48, 11.94, 11.94, 13.48, 16.07,
13.33, 9.93, 7.62, 7.62, 9.93, 13.33,
11.60, 7.35, 3.57, 3.57, 7.35, 11.60,
11.43, 7.07, 2.93, 2.93, 7.07, 11.43, 
12.89, 9.30, 6.77, 6.77, 9.30, 12.89,
15.47, 12.73, 11.07, 11.07, 12.73, 15.47,

/* outer crystals */
21.84, 19.29, 17.30, 16.18, 16.18, 17.30, 19.29, 21.84,
19.19, 19.19,
17.08, 17.08,
15.83, 15.83,
15.71, 15.71,
16.75, 16.75, 
18.72, 18.72,
21.29, 18.62, 16.53, 15.34, 15.34, 16.53, 18.62, 21.29
};


/*-- Module declaration --------------------------------------------*/

INT angle2(char*);
INT call_rotate2(INT run_number);
void rotate2(int axis, double a, double out_mat[3][3]);

ANGLE2_PARAM_STR(angle2_param_str);

ANA_MODULE angle2_module = {
  "Angle2",                       /* module name           */  
  "Penny Slocum",                 /* author                */
  angle2,                         /* event routine         */
  call_rotate2,                   /* BOR routine           */
  NULL,                           /* EOR routine           */
  call_rotate2,                   /* init routine          */
  NULL,                           /* exit routine          */
  &angle2_param,                  /* parameter structure   */
  sizeof(angle2_param),           /* structure size        */
  angle2_param_str,               /* initial parameters    */
};



void rotate2(int axis, double a, double out_mat[3][3])
{
int    i, j, k;
double rot_mat[3][3], in_mat[3][3];


  /* Convert to radians */
  a = a/180*PI;


  for (i=0 ; i<3 ; i++)
    for (j=0 ; j<3 ; j++)
      if (i == j)
        rot_mat[i][j] = 1;
      else
        rot_mat[i][j] = 0;

   if (axis == 0)
    {
    rot_mat[1][1] = cos(a);
    rot_mat[1][2] = -sin(a);
    rot_mat[2][1] = sin(a);
    rot_mat[2][2] = cos(a);
    }if (axis == 1)
    {
    rot_mat[0][0] = cos(a);
    rot_mat[0][2] = sin(a);
    rot_mat[2][0] = -sin(a);
    rot_mat[2][2] = cos(a);
    }
  if (axis == 2)
    {
    rot_mat[0][0] = cos(a);
    rot_mat[0][1] = -sin(a);
    rot_mat[1][0] = sin(a);
    rot_mat[1][1] = cos(a);
    }

/* Place OUT_MAT matrix into IN_MAT matrix, and zero OUT_MAT */
  for (i=0 ; i<3 ; i++)
    for (j=0 ; j<3 ; j++)
      {
      in_mat[i][j] = out_mat[i][j];
      out_mat[i][j] = 0;
      }

  /* Do matrix multiplication */
  for (i=0 ; i<3 ; i++)
    for (k=0 ; k<3 ; k++)
      for (j=0 ; j<3 ; j++)
        out_mat[i][k] = out_mat[i][k] + in_mat[i][j]*rot_mat[j][k];

}


/*------------------------------------------------------*/

INT call_rotate2(INT run_number)
/* Construct ROTATION MATRIX 'out_mat2' for transformation to Geant frame. */
{
int i, j;

  /* First, initialize rotation matrix to "1". */
  for (i=0 ; i<3 ; i++)
    for (j=0 ; j<3 ; j++)
      if (i == j)
        out_mat2[i][j] = 1;
      else
        out_mat2[i][j] = 0;

  /* Warning:  these rotations happen in the reverse order as entered. */

  /* Rotate the beam about the Z-axis for (Geant sys --> lab sys.) */
  rotate2(2, 90, out_mat2);

  /* Rotate the beam about the x-axis. ('phi' in swing language) */
  rotate2(0, exp_param.phi_swing, out_mat2);

  /* Rotate the beam about the y-axis. ('theta' in swing lingo.) */
  rotate2(1, 180+exp_param.theta_swing, out_mat2);


  /*  for (i=0 ; i<3 ; i++)
    for (j=0 ; j<3 ; j++)
      printf("out_mat2[%d][%d] is %f\n",i,j,out_mat2[i][j]);
      */
  return SUCCESS;
}


/*-- event routine -------------------------------------------------*/

INT angle2(char *pevent)
{
float        *cadc;
ASUM_BANK    *asum;
ANG2_BANK    *ang2;
int          i;
double       q, x_adc, y_adc, z_adc, x_97, y_97, z_97,
             z_boost, phi_97, theta_97, r_97, 
             sum_array, sum_q_a, theta_q, phi_q, sum_theta_q,
             sum_phi_q, adc_theta, adc_phi, check_rel_ang;
double       sum_x_q, sum_y_q, adc_x, adc_y;
double sphere_radius   = 260;
double sphere_offset_x = 23.34;
double sphere_offset_y = 0;
double sphere_offset_z = -1120.75;
double target_nai_dist = 1025;

  /* look for CADC bank, return if not present */
  if (bk_locate(pevent, "CADC", &cadc) == 0 ||
      bk_locate(pevent, "ASUM", &asum) == 0)
    return SUCCESS;

  /* create calculated bank ANGL */
  bk_create(pevent, "ANG2", TID_STRUCT, &ang2);

  /*---- perform calculations --------------------------------------*/

  /* Reconstructed hit point on sphere in Geant frame. */
  x_adc = 0;
  y_adc = 0;
  z_adc = 0;

  /* Distance between sphere center and lab origin */
  z_boost = -730.; /*mm*/

  /* Angular resolution calculation variables. */
  sum_array   = 0;
  sum_q_a     = 0;
  sum_theta_q = 0;
  sum_phi_q   = 0;

  /* Find coordinates of hit using ADC values. */

  if (asum->csi_max >= 0 && asum->csi_sum > 0)
    {
    for (i=0 ; i<N_CSI ; i++)
      {
      if (cadc[i] > global_param.adc_threshold)
        {
        q = cadc[i]/asum->csi_sum;

        sum_q_a = sum_q_a + pow(q, angle2_param.alpha);

        theta_q = csi_theta[csi_index[i]];
        phi_q   = csi_phi[csi_index[i]];
      
        sum_theta_q += theta_q*pow(q, angle2_param.alpha);
        sum_phi_q   += phi_q*pow(q, angle2_param.alpha);
        }
      }

    if (sum_q_a > 0)
      {
      adc_theta = sum_theta_q / sum_q_a;
      adc_phi   = sum_phi_q / sum_q_a;

      /* Convert adc angles to radians */
      adc_theta = PI*adc_theta/180;
      adc_phi   = PI*adc_phi/180;

      /* convert adc phi/theta to x/y/z */
      x_adc = sphere_radius*sin(adc_theta)*cos(adc_phi);
      y_adc = sphere_radius*sin(adc_theta)*sin(adc_phi);
      z_adc = sphere_radius*cos(adc_theta);

      /* rotate from Geant frame to lab frame */
      x_97 = out_mat2[0][0]*x_adc + out_mat2[0][1]*y_adc + out_mat2[0][2]*z_adc;
      y_97 = out_mat2[1][0]*x_adc + out_mat2[1][1]*y_adc + out_mat2[1][2]*z_adc;
      z_97 = out_mat2[2][0]*x_adc + out_mat2[2][1]*y_adc + out_mat2[2][2]*z_adc;

      /* boost back to put origin at H2 target */
      z_97 += z_boost; 

      r_97 = sqrt(sqr(x_97) + sqr(y_97) + sqr(z_97));
  
      /* phi 1997 */
      phi_97 = atan2(y_97, x_97);
      if (phi_97 < 0)
        phi_97 += 2*PI;

      /* theta 1997 */
      theta_97 = atan2(sqrt(sqr(x_97) + sqr(y_97)), z_97);
      if (theta_97 < 0)
        theta_97 += 2*PI;

      /* Convert csi_theta and csi_phi back to degrees */
      theta_97  = theta_97*180/PI;
      phi_97    = phi_97*180/PI;
      adc_phi   = adc_phi*180/PI;
      adc_theta = adc_theta*180/PI;
      } /* sum_q_a > 0 */
    else
      theta_97 = phi_97 = 1000;

    } /* csi_max >= 0 */

  else /* csi_max < 0, set overflow values */
    {
    theta_97=1000;
    phi_97=1000;
    }
    
  /* Set result values. */
  ang2->csi_theta = (float) theta_97;
  ang2->csi_phi = (float) phi_97;

  /*---- calculate theta/phi for NaI -------------------------------*/

  /* NaI shower center in cartesian coordinate system using Penny's energy weighting method */
  sum_q_a     = 0;
  sum_theta_q = 0;
  sum_phi_q   = 0;

  /* Find coordinates of hit using ADC values. */

  if (asum->nai_max >= 0 && asum->nai_sum > 0)
    {
    for (i=0 ; i<N_NAI ; i++)
      {
      if (cadc[i+CHN_NAI] > global_param.adc_threshold*5)
        {
        q = cadc[i+CHN_NAI]/asum->nai_sum;

        sum_q_a += pow(q, angle2_param.alpha);
        sum_x_q += nai_x[i]*pow(q, angle2_param.alpha);
        sum_y_q += nai_y[i]*pow(q, angle2_param.alpha);
        }
      }

    if (sum_q_a > 0)
      {
      adc_x = 63.5 * sum_x_q / sum_q_a;
      adc_y = 63.5 * sum_y_q / sum_q_a;
      }  /* sum_q_a > 0 */ 
    else /* sum_q_a <= 0 */
	    {
      adc_x = 1000.;
      adc_y = 1000.;
      }
    } /* NaI_max >= 0*/
  else /* set overflow values */
    {
    adc_x = 1000.;
    adc_y = 1000.;
    }  

  /* convert shower center x/y to theta/phi */
  ang2->nai_phi = (float) atan2(adc_y, adc_x);
  ang2->nai_theta = (float) atan2(sqrt(sqr(adc_x) + sqr(adc_y)), target_nai_dist);

  if (ang2->nai_theta < 0)
    ang2->nai_theta += (float) (2*PI);
  if (ang2->nai_phi < 0)
    ang2->nai_phi += (float) (2*PI);

  ang2->nai_theta *= (float) (180/PI);
  ang2->nai_phi   *= (float) (180/PI);
  
  /* set temporary NaI angles based only on NaI_max. */
/*
  ang2->nai_theta = (float) nai_theta[asum->nai_max];
  ang2->nai_phi = (float) nai_phi[asum->nai_max];
*/

  /* test: convert theta/phi to x/y */
/*
  ang2->nai_theta *= (float) (PI/180);
  ang2->nai_phi   *= (float) (PI/180);

  x_adc = target_nai_dist*sin(ang2->nai_theta)*cos(ang2->nai_phi);
  y_adc = target_nai_dist*sin(ang2->nai_theta)*sin(ang2->nai_phi);
  z_adc = target_nai_dist*cos(ang2->nai_theta);

  ang2->nai_theta = (float) y_adc;
  ang2->nai_phi = (float) x_adc;
*/

  /* Calculate relative angle between reconstructed CsI and NaI angles */
  check_rel_ang = cos(PI/180*ang2->csi_theta)*cos(PI/180*ang2->nai_theta) 
                + sin(PI/180*ang2->csi_theta)*
                  sin(PI/180*ang2->nai_theta)*
                  cos(PI/180*ang2->nai_phi - PI/180*ang2->csi_phi);

  if (check_rel_ang < 1 && check_rel_ang > -1)
    ang2->rel_ang = (float) (180/PI*acos(check_rel_ang));
  else
    if (check_rel_ang >= 1)
      ang2->rel_ang = 0.f;
    else
      ang2->rel_ang = 180.f;

  /*---- close calculated bank -------------------------------------*/
  bk_close(pevent, ang2+1);
  
  return SUCCESS;
}
