/********************************************************************\

  Name:         cluster.c
  Created by:   Penny Slocum

  Contents:     PiBeta Analyzer module for cluster


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  JUN 21 97    PLS   created


\********************************************************************/
                                                        
/*-- Include files -------------------------------------------------*/

/* standard includes */
#include <stdio.h>
#include <math.h>
/* midas includes */
#include "midas.h"
#include "hardware.h"
#include "event.h"

/*-- Parameters ----------------------------------------------------*/
extern GLOBAL_PARAM global_param;
extern EXP_PARAM exp_param;
extern double csi_theta[240];
extern double csi_phi[240];
CLUSTER_PARAM cluster_param;
ANGLE_PARAM angle_param;

/*-- Static parameters ---------------------------------------------*/
#define N_CSI 44
#ifndef PI
#define PI 3.14159265359
#endif


/*-- Module declaration --------------------------------------------*/

INT cluster(char*);
INT apply_mask(int *mask_counter,int *mask_counter_whole_detector,
    double 
    adc_theta,double adc_phi,double angle, int list[]);
INT find_hit_coordinates(int n,double *adc_theta,
    double *adc_phi,double ar[],int list[]);
INT insertion_sort(int *n, double ar[], int index[]);
INT begin_cluster(char*);

ANA_MODULE cluster_module = {
  "cluster",                     /* module name           */  
  "Penny Slocum",                /* author                */
  NULL,                          /* BOR routine           */
  NULL,                          /* EOR routine           */
  cluster,                       /* event routine         */
  &cluster_param,                /* parameter structure   */
  sizeof(cluster_param),         /* structure size        */
  CLUSTER_PARAM_STR,             /* initial parameters    */
};

/*-- event routine -------------------------------------------------*/

INT insertion_sort(int *n, double arrin[], int index[] )
{
int i,j,b;
double a;
*n=0;


for (j=0; j<N_CSI; j++)
  index[j]=j;

for (j=1; j<N_CSI; j++)
  {
  a=arrin[j];
  b=index[j];
  if (a>0.) *n+=1;
  for (i=j-1; i>=0; i--)
    {
    if (arrin[i] <= a) break;
    arrin[i+1] = arrin[i];
    index[i+1] = index[i];
    } 
  arrin[i+1]=a;
  index[i+1]=b;
  }

if (*n>3) *n=3;  

}

INT apply_mask(int *mask_counter,int *mask_counter_whole_detector,
    double 
    adc_theta,double adc_phi,double angle, int list[])
{
double ang_sep;
int i,j;
int csi_index[] = {
  115, 164, 191, 124,  74, 120, 168, 195, 129,  15,  /*  0: 9 */
   65, 170,  73,  24,  20,  70, 174,  78,  29,  16,  /* 10:19 */
  116, 123,  23,   2,  21, 121, 128,  28,  66, 165,  /* 20:29 */
   72,  22,  71, 169,  77, 203, 204, 122, 205, 206,  /* 30:39 */
  223, 224, 225, 226 };                              /* 40:43 */

*mask_counter=0;
*mask_counter_whole_detector=0;

for (i=0; i<N_CSI; i++)
  list[i]=0;

for (j=0; j<N_CSI; j++)
  {
  ang_sep=sin(adc_theta)*cos(adc_phi)*sin(csi_theta[csi_index[j]]*PI/180.)*
     cos(csi_phi[csi_index[j]]*PI/180.) +
     sin(adc_theta)*sin(adc_phi)*sin(csi_theta[csi_index[j]]*PI/180.)*
     sin(csi_phi[csi_index[j]]*PI/180.)+cos(adc_theta)*
     cos(csi_theta[csi_index[j]]*PI/180.);
  if ((ang_sep < 1.)&&(ang_sep > -1.)) 
    ang_sep=acos(ang_sep);
  else
    {
    if (ang_sep >= 1.) 
      ang_sep=0.;
    if (ang_sep <=-1.) 
      ang_sep=PI;
    }

  ang_sep = 180.*ang_sep/PI;
  if (ang_sep < angle)
    {
    list[*mask_counter]=j;
    *mask_counter += 1;
    }
  }
for (j=0; j<240; j++)
  {
  ang_sep=sin(adc_theta)*cos(adc_phi)*sin(csi_theta[j]*PI/180.)*
    cos(csi_phi[j]*PI/180.) +
    sin(adc_theta)*sin(adc_phi)*sin(csi_theta[j]*PI/180.)*
    sin(csi_phi[j]*PI/180.)+cos(adc_theta)*
    cos(csi_theta[j]*PI/180.);
  if ((ang_sep < 1.)&&(ang_sep > -1.))
    ang_sep=acos(ang_sep);
  else
    {
    if (ang_sep >= 1.)
      ang_sep=0.;
    if (ang_sep <=-1.)
      ang_sep=PI;
    }
  ang_sep = 180.*ang_sep/PI;
  if (ang_sep < angle)
    *mask_counter_whole_detector += 1;
  }  
}

INT find_hit_coordinates(int n,double *adc_theta,
  double *adc_phi, double ar[], int list[])
{
  double sum_array,q[240]={0.0},sum_q_a,theta_q,phi_q,
     sum_theta_q,sum_phi_q,adc_max; 
  int i, cno_max;

int csi_index[] = {
  115, 164, 191, 124,  74, 120, 168, 195, 129,  15,  /*  0: 9 */
   65, 170,  73,  24,  20,  70, 174,  78,  29,  16,  /* 10:19 */
  116, 123,  23,   2,  21, 121, 128,  28,  66, 165,  /* 20:29 */ 
   72,  22,  71, 169,  77, 203, 204, 122, 205, 206,  /* 30:39 */
  223, 224, 225, 226 };                              /* 40:43 */

  sum_array=0.;
  *adc_theta=0.;
  *adc_phi=0.;
  sum_q_a=0.;
  sum_theta_q=0.;
  sum_phi_q=0.;
  cno_max=0;
  adc_max=0.;

  if (n > 0) 
    for (i=0; i<n; i++)
      {
      if (ar[list[i]] > global_param.adc_threshold) 
        sum_array += ar[list[i]];
      
      if (ar[list[i]] > adc_max)
        {
        cno_max = list[i];
        adc_max = ar[list[i]];
        }
      }

     if (adc_max > global_param.adc_threshold)
       {

       for (i=0; i<n; i++)
         {
         if (ar[list[i]] > global_param.adc_threshold)
           q[list[i]]=ar[list[i]]/sum_array;
         sum_q_a = sum_q_a + pow(q[list[i]],angle_param.alpha);
         theta_q = csi_theta[csi_index[list[i]]];
         phi_q = csi_phi[csi_index[list[i]]];
         sum_theta_q += theta_q*pow(q[list[i]],angle_param.alpha);
         sum_phi_q += phi_q*pow(q[list[i]],angle_param.alpha);
         }
         *adc_theta = sum_theta_q/sum_q_a;
         *adc_phi = sum_phi_q/sum_q_a;
         *adc_theta = *adc_theta*PI/180.;
         *adc_phi = *adc_phi*PI/180.;

       }
}

INT cluster(char *pevent)
{
int          m;
double ar[N_CSI];
CADC_BANK    *cadc;
CLUS_BANK    *clus;
double sum_array,adc_phi,adc_theta,angle;
int n,i,list[240]={0},n_whole_detector;
adc_theta=0;
adc_phi=0;

  /* look for CADC bank, return if not present */
  m = bk_locate(pevent, "CADC", &cadc);
  if (m == 0)
    return SUCCESS;

  /* create calculated bank */
  bk_create(pevent, "CLUS", TID_STRUCT, &clus);


/*angle=12.;*/          /* ~ 3 detectors  */
/*angle=20.;*/      /* ~1 ring around single crystal */
angle=30.;     /* ~2 rings around single crystal */
/*angle=360.;*/ /* Whole detector */


for (i=0; i<N_CSI; i++)
  ar[i] = cadc->cadc[i];
insertion_sort(&n,ar,list); 
for (i=0; i<3; i++)  /* Invert results of insertion sort. */
  list[i] = list[N_CSI-1-i];
for (i=0; i<N_CSI; i++)
  ar[i] = cadc->cadc[i];

find_hit_coordinates(n,&adc_theta,&adc_phi,ar,list);  
			/* Find hit point in top 3 */

apply_mask(&n,&n_whole_detector,adc_theta,adc_phi,angle,list); 
                        /* Mask around top 3 */ 

find_hit_coordinates(n,&adc_theta,&adc_phi,ar,list); 
			/* Find hit point in mask */ 

apply_mask(&n,&n_whole_detector,adc_theta,adc_phi,angle,list); 
			/* Final mask around new hit point */

clus->num_cluster = n;
clus->num_cluster_whole_detector = n_whole_detector;

for (i=0; i<N_CSI; i++)
  if (i<n)
    clus->cluster[i] = list[i];
  else
    clus->cluster[i] = 0;

clus->sum_array=0.;		/* Sum crystals in final mask */
for (i=0; i<clus->num_cluster; i++)
  if (cadc->cadc[clus->cluster[i]] > global_param.adc_threshold) 
    clus->sum_array += cadc->cadc[clus->cluster[i]];

  bk_close(pevent, clus+1);
  
  return SUCCESS;
}
