/********************************************************************\

  Name:         dave.c
  Created by:   Stefan Ritt

  Contents:     PiBeta Analyzer module for <template>


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  <date>       <XX>  created
  7-13-97     Dave L. Target calibration coding


\********************************************************************/
                                                        
/*-- Include files -------------------------------------------------*/

/* standard includes */
#include <stdio.h>

/* midas includes */
#include "midas.h"
#include "hardware.h"
#include "event.h"

/*-- Parameters ----------------------------------------------------*/

CTGT_PARAM ctgt_param;
CTGT_PARAM_STR(ctgt_param_str);

/* define some global pointers to save many "ctgt_param->"s */
#define A (&ctgt_param.a)
#define B (&ctgt_param.b)
#define C (&ctgt_param.c)
#define D (&ctgt_param.d)
#define E (&ctgt_param.e)
#define F (&ctgt_param.f)
#define G (&ctgt_param.g)
#define cutoff (&ctgt_param.cutoff)
#define cfac (&ctgt_param.cfac)

/*-- Static parameters ---------------------------------------------*/


/*-- Module declaration --------------------------------------------*/

INT ctgt_er(char*);
INT ctgt_init(void);

ANA_MODULE ctgt_module = {
  "ctgt",                        /* module name           */  
  "David Lawrence",              /* author                */
  ctgt_er,                          /* event routine         */
  NULL,                          /* BOR routine           */
  NULL,                          /* EOR routine           */
  ctgt_init,                          /* init routine           */
  NULL,                          /* exit routine           */
  &ctgt_param,                   /* parameter structure   */
  sizeof(ctgt_param),            /* structure size        */
  ctgt_param_str,                /* initial parameters    */
  1	                           /* enabled flag          */
};

INT ctgt_init(void)
{
  printf("Dave's target calibration module initialized.\n");

  return SUCCESS;
}
/*-- event routine -------------------------------------------------*/

INT ctgt_er(char *pevent)
{
int          n;
float        *cadc,*thit;
ASUM_BANK    *asum;
CTGT_BANK    *ctgt;
float tD0,a;
float T0,T0d,tail;
float sum;

  /* look for CADC bank, return if not present */
  n = bk_locate(pevent, "CADC", &cadc);
  if (n == 0)return SUCCESS;
  /* look for ASUM bank, return if not present */
  n = bk_locate(pevent, "ASUM", &asum);
  if (n == 0)return SUCCESS;
  /* look for THIT bank, return if not present */
  n = bk_locate(pevent, "THIT", &thit);
  if (n == 0)return SUCCESS;

	T0=cadc[47];
   T0d=(float)1.0*cadc[71];
	sum=asum->csi_sum;

  /* create calculated bank */
  bk_create(pevent, "CTGT", TID_STRUCT, &ctgt);

  /*---- perform calculations --------------------------------------*/
  tD0=(float)thit[46];
	/*The amplitude (A) should probably be 1.0 to force proper asymptotic behavior*/
	/* Nominal values: A=1.0 B=8630.05 C=426.15 D=29899.5 
	                   E=-8.81154 F=0.0968837 G=-0.000252656
                     cutoff=220 cfac=0.3772
	*/
	if(tD0<*cutoff){
		a=(float)(*C-tD0);
		a=(float)((a*a)-(*D));
    a=(float)((*A)*( 1.0-(*B/a) ));
 	}else{
		a=(float)((*E) + ((*F)*tD0) + ((*G)*tD0*tD0));
	} 

	if(a!=0.0)tail=(float)(T0d*((1.0/a) -1.0));

/*if(tD0>=53){
	if(tD0<=70){
		tail=(float)((30.0*(tD0-53.0)) + 150.0);
	}else{
		tail=(float)600.0;
	}
	a=(float)1.0;
}
*/
  if(a>0.0 && a<1.3){
    ctgt->edge_func=(double)tail;
	  ctgt->e__in_tgt=(double)(T0-tail);
  
    ctgt->e__in_tgt=(ctgt->e__in_tgt<0.0 ? 0.0:ctgt->e__in_tgt>4000.0 ? 4000.0:ctgt->e__in_tgt);
  }else{
        ctgt->edge_func=0.0;
 	      ctgt->e__in_tgt=T0;
	      ctgt->sumtgt=0.0;
 }
	  ctgt->sumtgt=sum + (*cfac)*ctgt->e__in_tgt;
    ctgt->sumtgt=(ctgt->sumtgt<0.0 ? 0.0:ctgt->sumtgt>4000.0 ? 4000.0:ctgt->sumtgt);

   /*---- close calculated bank -------------------------------------*/
  bk_close(pevent, ctgt+1);
  
  return SUCCESS;
}












