/********************************************************************\

  Name:         event.h
  Created by:   ODBedit program

  Contents:     This file contains C structures for the "Runinfo"
                tree in the ODB and the "/Analyzer/Parameters" tree.

                Additionally, it contains the "Settings" subtree for
                all items listed under "/Equipment" as well as their
                event definition.

                It can be used by the frontend and analyzer to work
                with these information.

                All C structures are accompanied with a string represen-
                tation which can be used in the db_create_record function
                to setup an ODB structure which matches the C structure.

  Created on:   Wed May  7 17:33:15 1997

\********************************************************************/

typedef struct {
  INT       state;
  INT       online_mode;
  INT       run_number;
  char      start_time[32];
} RUNINFO;

#define RUNINFO_STR "\
State = INT : 1\n\
Online Mode = INT : 0\n\
Run number = INT : 1\n\
Start time = STRING : [32] Wed Apr 09 18:23:02 1997\n\
"

typedef struct {
  BOOL      pedestal_run;
  float     theta_swing;
  float     phi_swing;
} EXP_PARAM;

#define EXP_PARAM_STR "\
Pedestal run = BOOL : 0\n\
Theta Swing = FLOAT : 0\n\
Phi Swing = FLOAT : 0\n\
"

typedef struct {
  float     adc_threshold;
} GLOBAL_PARAM;

#define GLOBAL_PARAM_STR "\
ADC Threshold = FLOAT : 5\n\
"

typedef struct {
  WORD      pedestal[74];
  float     software_gain[44];
  float     pedestal_threshold[74];
} ADC_CALIBRATION_PARAM;

#define ADC_CALIBRATION_PARAM_STR "\
Pedestal = WORD[74] :\n\
[0] 204\n\
[1] 224\n\
[2] 204\n\
[3] 210\n\
[4] 213\n\
[5] 239\n\
[6] 211\n\
[7] 210\n\
[8] 222\n\
[9] 229\n\
[10] 202\n\
[11] 206\n\
[12] 204\n\
[13] 226\n\
[14] 201\n\
[15] 210\n\
[16] 233\n\
[17] 245\n\
[18] 227\n\
[19] 219\n\
[20] 214\n\
[21] 240\n\
[22] 214\n\
[23] 215\n\
[24] 209\n\
[25] 229\n\
[26] 219\n\
[27] 233\n\
[28] 220\n\
[29] 236\n\
[30] 223\n\
[31] 222\n\
[32] 232\n\
[33] 253\n\
[34] 257\n\
[35] 238\n\
[36] 236\n\
[37] 256\n\
[38] 241\n\
[39] 248\n\
[40] 275\n\
[41] 289\n\
[42] 271\n\
[43] 280\n\
[44] 225\n\
[45] 261\n\
[46] 210\n\
[47] 217\n\
[48] 286\n\
[49] 309\n\
[50] 293\n\
[51] 289\n\
[52] 276\n\
[53] 301\n\
[54] 280\n\
[55] 290\n\
[56] 280\n\
[57] 302\n\
[58] 279\n\
[59] 283\n\
[60] 279\n\
[61] 298\n\
[62] 281\n\
[63] 278\n\
[64] 247\n\
[65] 245\n\
[66] 227\n\
[67] 220\n\
[68] 233\n\
[69] 189\n\
[70] 239\n\
[71] 238\n\
[72] 224\n\
[73] 245\n\
Software Gain = FLOAT[44] :\n\
[0] 1\n\
[1] 1\n\
[2] 1\n\
[3] 1\n\
[4] 0.997\n\
[5] 0.955\n\
[6] 0.976\n\
[7] 1\n\
[8] 1\n\
[9] 1\n\
[10] 1\n\
[11] 1\n\
[12] 1\n\
[13] 1\n\
[14] 0.968\n\
[15] 0.955\n\
[16] 1.02\n\
[17] 1\n\
[18] 1\n\
[19] 1\n\
[20] 1\n\
[21] 1\n\
[22] 1\n\
[23] 1.004\n\
[24] 0.939\n\
[25] 0.957\n\
[26] 0.974\n\
[27] 0.961\n\
[28] 1\n\
[29] 1\n\
[30] 1\n\
[31] 0.977\n\
[32] 0.97\n\
[33] 0.942\n\
[34] 1\n\
[35] 1\n\
[36] 1\n\
[37] 0.919\n\
[38] 0.899\n\
[39] 1\n\
[40] 1\n\
[41] 1\n\
[42] 1\n\
[43] 1\n\
Pedestal Threshold = FLOAT[74] :\n\
[0] 63.624\n\
[1] 64.338\n\
[2] 64.184\n\
[3] 67.571\n\
[4] 67.536\n\
[5] 67.729\n\
[6] 64.275\n\
[7] 53.967\n\
[8] 64.747\n\
[9] 63.915\n\
[10] 63.863\n\
[11] 63.964\n\
[12] 63.747\n\
[13] 63.955\n\
[14] 63.652\n\
[15] 64.238\n\
[16] 68.422\n\
[17] 63.089\n\
[18] 68.444\n\
[19] 68.654\n\
[20] 68.792\n\
[21] 68.686\n\
[22] 68.568\n\
[23] 68.598\n\
[24] 68.286\n\
[25] 67.866\n\
[26] 69.098\n\
[27] 69.022\n\
[28] 68.177\n\
[29] 68.204\n\
[30] 67.96\n\
[31] 68.251\n\
[32] 55.961\n\
[33] 55.39\n\
[34] 43.892\n\
[35] 54.836\n\
[36] 54.724\n\
[37] 54.787\n\
[38] 54.698\n\
[39] 54.811\n\
[40] 47.691\n\
[41] 47.781\n\
[42] 44.219\n\
[43] 43.685\n\
[44] 54.739\n\
[45] 43.507\n\
[46] 54.361\n\
[47] 53.748\n\
[48] 55.25\n\
[49] 55.011\n\
[50] 55.942\n\
[51] 55.64\n\
[52] 55.199\n\
[53] 55.186\n\
[54] 54.977\n\
[55] 67.784\n\
[56] 67.536\n\
[57] 67.729\n\
[58] 64.275\n\
[59] 53.967\n\
[60] 64.747\n\
[61] 63.915\n\
[62] 63.863\n\
[63] 63.964\n\
[64] 63.747\n\
[65] 63.955\n\
[66] 63.652\n\
[67] 64.238\n\
[68] 68.422\n\
[69] 63.089\n\
[70] 68.444\n\
[71] 68.654\n\
[72] 68.792\n\
[73] 68.686\n\
"

typedef struct {
  float     factor[4];
  float     offset[4];
} MWPC_CALIBRATION_PARAM;

#define MWPC_CALIBRATION_PARAM_STR "\
Factor = FLOAT[4] :\n\
[0] -1\n\
[1] 1\n\
[2] 1\n\
[3] 1\n\
Offset = FLOAT[4] :\n\
[0] -128\n\
[1] 128\n\
[2] 64\n\
[3] 64\n\
"

typedef struct {
  float     alpha;
} ANGLE_PARAM;

#define ANGLE_PARAM_STR "\
Alpha = FLOAT : 0.72\n\
"

typedef struct {
  float     cadc[74];
  float     adc_sum;
} CADC_BANK;

#define CADC_BANK_STR "\
CADC = FLOAT[74] :\n\
[0] 0.75\n\
[1] -0.25\n\
[2] 0.75\n\
[3] -1.25\n\
[4] 0.3988\n\
[5] 2.292\n\
[6] -0.5856\n\
[7] 0\n\
[8] 0.4\n\
[9] -2.6\n\
[10] 0.200001\n\
[11] 1.2\n\
[12] 0.200001\n\
[13] 0.200001\n\
[14] 290.594\n\
[15] -1.719\n\
[16] 0.408\n\
[17] 0\n\
[18] 3.4\n\
[19] -2.6\n\
[20] -0.6\n\
[21] -0.6\n\
[22] -1\n\
[23] 0\n\
[24] 0\n\
[25] 0.957\n\
[26] 2.11033\n\
[27] 2.08217\n\
[28] -0.833334\n\
[29] -0.833334\n\
[30] -1.83333\n\
[31] -0.814167\n\
[32] 0.7275\n\
[33] -1.1775\n\
[34] 0\n\
[35] -0.25\n\
[36] 0.75\n\
[37] -1.53167\n\
[38] 0.299667\n\
[39] 1.33333\n\
[40] 0\n\
[41] 1\n\
[42] 0\n\
[43] -1\n\
[44] 84\n\
[45] -33\n\
[46] -37\n\
[47] -38\n\
[48] 1.33333\n\
[49] -0.666668\n\
[50] -0.666668\n\
[51] 443.333\n\
[52] -0.666668\n\
[53] 0.333332\n\
[54] 0.333332\n\
[55] 1\n\
[56] -1\n\
[57] 1\n\
[58] -1\n\
[59] 688\n\
[60] 0\n\
[61] 0\n\
[62] -0.5\n\
[63] 0.5\n\
[64] -22\n\
[65] -32\n\
[66] -32\n\
[67] -34\n\
[68] -18\n\
[69] 968\n\
[70] -77\n\
[71] -77\n\
[72] -75\n\
[73] -80\n\
ADC Sum = FLOAT : 290.594\n\
"

typedef struct {
  float     xa;
  float     ya;
  float     xb;
  float     yb;
} MWPC_BANK;

#define MWPC_BANK_STR "\
xa = FLOAT : -12\n\
ya = FLOAT : 3\n\
xb = FLOAT : -34\n\
yb = FLOAT : 17\n\
"

typedef struct {
  double    x;
  double    y;
  double    z;
  double    x_adc;
  double    y_adc;
  double    z_adc;
  double    angle_of_incidence;
  double    angular_resolution;
} ANGL_BANK;

#define ANGL_BANK_STR "\
x = DOUBLE : -247.802\n\
y = DOUBLE : -46.6676\n\
z = DOUBLE : 83.9584\n\
x ADC = DOUBLE : -246.534\n\
y ADC = DOUBLE : -30.1308\n\
z ADC = DOUBLE : 76.8971\n\
Angle of incidence = DOUBLE : 16.8065\n\
Angular resolution = DOUBLE : 3.72308\n\
"

typedef struct {
  WORD      io506_slot;
  WORD      adc0_slot;
  WORD      tdc0_slot;
  WORD      dbi_slot;
  struct {
    WORD      slot[12];
    WORD      plane[12];
    float     threshold[12];
    WORD      delay[12];
  } pcos;
} TRIGGER_SETTINGS;

#define TRIGGER_SETTINGS_STR "\
IO506 slot = WORD : 23\n\
ADC0 slot = WORD : 8\n\
TDC0 slot = WORD : 9\n\
DBI slot = WORD : 12\n\
[PCOS]\n\
Slot = WORD[12] :\n\
[0] 4\n\
[1] 5\n\
[2] 6\n\
[3] 7\n\
[4] 8\n\
[5] 9\n\
[6] 10\n\
[7] 11\n\
[8] 13\n\
[9] 14\n\
[10] 15\n\
[11] 16\n\
Plane = WORD[12] :\n\
[0] 0\n\
[1] 0\n\
[2] 0\n\
[3] 0\n\
[4] 1\n\
[5] 1\n\
[6] 1\n\
[7] 1\n\
[8] 2\n\
[9] 2\n\
[10] 3\n\
[11] 3\n\
Threshold = FLOAT[12] :\n\
[0] 4\n\
[1] 4\n\
[2] 4\n\
[3] 4\n\
[4] 4\n\
[5] 4\n\
[6] 4\n\
[7] 4\n\
[8] 4\n\
[9] 4\n\
[10] 4\n\
[11] 4\n\
Delay = WORD[12] :\n\
[0] 480\n\
[1] 480\n\
[2] 480\n\
[3] 480\n\
[4] 480\n\
[5] 480\n\
[6] 480\n\
[7] 480\n\
[8] 480\n\
[9] 480\n\
[10] 480\n\
[11] 480\n\
"

typedef struct {
  WORD      scaler0_slot;
  WORD      first_channel;
  WORD      last_channel;
} SCALER_SETTINGS;

#define SCALER_SETTINGS_STR "\
Scaler0 slot = WORD : 10\n\
First channel = WORD : 0\n\
Last channel = WORD : 1\n\
"

typedef struct {
  float     input[11];
  float     output[2];
} TEMPERATURE_EVENT;

#define TEMPERATURE_EVENT_STR "\
Input = FLOAT[11] :\n\
[0] 17.58\n\
[1] 16.29\n\
[2] 16.73\n\
[3] 17.98\n\
[4] 17.08\n\
[5] 7.78\n\
[6] 17.66\n\
[7] 26\n\
[8] 51.07\n\
[9] 17.94\n\
[10] 40.48\n\
Output = FLOAT[2] :\n\
[0] 0\n\
[1] 0\n\
"

typedef struct {
  char      names_input[11][32];
  char      names_output[2][32];
  float     update_threshold[11];
  float     input_offset[11];
  float     output_offset[2];
  float     input_factor[11];
  float     output_factor[2];
  struct {
    INT       null_i;
    INT       null_o;
    INT       null_i2;
    INT       dastemp;
    INT       das_1600_ai;
    INT       das_1600_ao;
  } channels;
  struct {
    struct {
      WORD      io_base;
    } dastemp;
    struct {
      WORD      io_base;
      WORD      gain[16];
    } das_1600_ai;
    struct {
      WORD      io_base;
      WORD      gain[16];
    } das_1600_ao;
  } devices;
} TEMPERATURE_SETTINGS;

#define TEMPERATURE_SETTINGS_STR "\
Names Input = STRING[11] :\n\
[32] Temp. 1\n\
[32] Temp. 2\n\
[32] Temp. 3\n\
[32] Temp. 4\n\
[32] Temp. 5\n\
[32] Temp. 6\n\
[32] Temp. 7\n\
[32] Hum. Temp. outside\n\
[32] Humidity outside\n\
[32] Hum. Temp. inside\n\
[32] Humudity inside\n\
Names Output = STRING[2] :\n\
[32] DAC0\n\
[32] DAC1\n\
Update Threshold = FLOAT[11] :\n\
[0] 0.1\n\
[1] 0.1\n\
[2] 0.1\n\
[3] 0.1\n\
[4] 0.1\n\
[5] 0.1\n\
[6] 0.1\n\
[7] 0.1\n\
[8] 0.5\n\
[9] 0.1\n\
[10] 0.5\n\
Input Offset = FLOAT[11] :\n\
[0] 0\n\
[1] 0\n\
[2] 0\n\
[3] 0\n\
[4] 0\n\
[5] 0\n\
[6] 0\n\
[7] 20\n\
[8] 0\n\
[9] 20\n\
[10] 0\n\
Output Offset = FLOAT[2] :\n\
[0] 0\n\
[1] 0\n\
Input Factor = FLOAT[11] :\n\
[0] 1\n\
[1] 1\n\
[2] 1\n\
[3] 1\n\
[4] 1\n\
[5] 1\n\
[6] 1\n\
[7] 10\n\
[8] 10\n\
[9] 10\n\
[10] 10\n\
Output Factor = FLOAT[2] :\n\
[0] 1\n\
[1] 1\n\
[Channels]\n\
NULL I = INT : 2\n\
NULL O = INT : 2\n\
NULL I2 = INT : 2\n\
DASTEMP = INT : 7\n\
DAS-1600 AI = INT : 4\n\
DAS-1600 AO = INT : 2\n\
[Devices/DASTEMP]\n\
IO Base = WORD : 544\n\
[Devices/DAS-1600 AI]\n\
IO Base = WORD : 576\n\
Gain = WORD[16] :\n\
[0] 1\n\
[1] 1\n\
[2] 1\n\
[3] 1\n\
[4] 1\n\
[5] 1\n\
[6] 1\n\
[7] 1\n\
[8] 1\n\
[9] 1\n\
[10] 1\n\
[11] 1\n\
[12] 1\n\
[13] 1\n\
[14] 1\n\
[15] 1\n\
[Devices/DAS-1600 AO]\n\
IO Base = WORD : 576\n\
Gain = WORD[16] :\n\
[0] 1\n\
[1] 1\n\
[2] 1\n\
[3] 1\n\
[4] 1\n\
[5] 1\n\
[6] 1\n\
[7] 1\n\
[8] 1\n\
[9] 1\n\
[10] 1\n\
[11] 1\n\
[12] 1\n\
[13] 1\n\
[14] 1\n\
[15] 1\n\
"

typedef struct {
  float     demand[16];
  float     measured[16];
  float     current[16];
} HV_EVENT;

#define HV_EVENT_STR "\
Demand = FLOAT[16] :\n\
[0] 1000\n\
[1] 0\n\
[2] 0\n\
[3] 0\n\
[4] 0\n\
[5] 0\n\
[6] 0\n\
[7] 0\n\
[8] 2000\n\
[9] 0\n\
[10] 0\n\
[11] 0\n\
[12] 0\n\
[13] 0\n\
[14] 0\n\
[15] 0\n\
Measured = FLOAT[16] :\n\
[0] 999\n\
[1] 40\n\
[2] 0\n\
[3] 0\n\
[4] 0\n\
[5] 0\n\
[6] 2\n\
[7] 153\n\
[8] 2001\n\
[9] 154\n\
[10] 3\n\
[11] 0\n\
[12] 0\n\
[13] 0\n\
[14] 0\n\
[15] 0\n\
Current = FLOAT[16] :\n\
[0] 0\n\
[1] 0\n\
[2] 0\n\
[3] 0\n\
[4] 0\n\
[5] 0\n\
[6] 0\n\
[7] 0\n\
[8] 0\n\
[9] 0\n\
[10] 0\n\
[11] 0\n\
[12] 0\n\
[13] 0\n\
[14] 0\n\
[15] 0\n\
"

typedef struct {
  char      names[16][32];
  float     update_threshold_measured[16];
  float     update_threshold_current[16];
  float     voltage_limit[16];
  float     current_limit[16];
  float     ramping_speed[16];
  struct {
    INT       lrs1440;
  } channels;
  struct {
    struct {
      char      rs232_port[32];
      INT       polarity;
    } lrs1440;
  } devices;
} HV_SETTINGS;

#define HV_SETTINGS_STR "\
Names = STRING[16] :\n\
[32] Default%CH 0\n\
[32] Default%CH 1\n\
[32] Default%CH 2\n\
[32] Default%CH 3\n\
[32] Default%CH 4\n\
[32] Default%CH 5\n\
[32] Default%CH 6\n\
[32] Default%CH 7\n\
[32] Default%CH 8\n\
[32] Default%CH 9\n\
[32] Default%CH 10\n\
[32] Default%CH 11\n\
[32] Default%CH 12\n\
[32] Default%CH 13\n\
[32] Default%CH 14\n\
[32] Default%CH 15\n\
Update Threshold Measured = FLOAT[16] :\n\
[0] 2\n\
[1] 2\n\
[2] 2\n\
[3] 2\n\
[4] 2\n\
[5] 2\n\
[6] 2\n\
[7] 2\n\
[8] 2\n\
[9] 2\n\
[10] 2\n\
[11] 2\n\
[12] 2\n\
[13] 2\n\
[14] 2\n\
[15] 2\n\
Update Threshold Current = FLOAT[16] :\n\
[0] 2\n\
[1] 2\n\
[2] 2\n\
[3] 2\n\
[4] 2\n\
[5] 2\n\
[6] 2\n\
[7] 2\n\
[8] 2\n\
[9] 2\n\
[10] 2\n\
[11] 2\n\
[12] 2\n\
[13] 2\n\
[14] 2\n\
[15] 2\n\
Voltage Limit = FLOAT[16] :\n\
[0] 3000\n\
[1] 3000\n\
[2] 3000\n\
[3] 3000\n\
[4] 3000\n\
[5] 3000\n\
[6] 3000\n\
[7] 3000\n\
[8] 3000\n\
[9] 3000\n\
[10] 3000\n\
[11] 3000\n\
[12] 3000\n\
[13] 3000\n\
[14] 3000\n\
[15] 3000\n\
Current Limit = FLOAT[16] :\n\
[0] 3000\n\
[1] 3000\n\
[2] 3000\n\
[3] 3000\n\
[4] 3000\n\
[5] 3000\n\
[6] 3000\n\
[7] 3000\n\
[8] 3000\n\
[9] 3000\n\
[10] 3000\n\
[11] 3000\n\
[12] 3000\n\
[13] 3000\n\
[14] 3000\n\
[15] 3000\n\
Ramping Speed = FLOAT[16] :\n\
[0] 0\n\
[1] 0\n\
[2] 0\n\
[3] 0\n\
[4] 0\n\
[5] 0\n\
[6] 0\n\
[7] 0\n\
[8] 0\n\
[9] 0\n\
[10] 0\n\
[11] 0\n\
[12] 0\n\
[13] 0\n\
[14] 0\n\
[15] 0\n\
[Channels]\n\
LRS1440 = INT : 16\n\
[Devices/LRS1440]\n\
RS232 Port = STRING : [32] COM1\n\
Polarity = INT : -1\n\
"

