/********************************************************************\

  Name:         histo.c
  Created by:   Stefan Ritt

  Contents:     General purpos histogram booking/filling module


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  17-JUL-97    SR    created

\********************************************************************/
                                                        
/*-- Include files -------------------------------------------------*/

/* standard includes */
#include <stdio.h>
#include <math.h>

/* midas includes */
#include "midas.h"
#include "event.h"
#include "analyzer.h"

/* cernlib includes */
#ifdef OS_WINNT
#define VISUAL_CPLUSPLUS
#endif

#ifdef __linux__
#define f2cFortran
#endif

#include <cfortran.h>
#include <hbook.h>

/*-- Parameters ----------------------------------------------------*/

/*-- Static parameters ---------------------------------------------*/

/*-- Module declaration --------------------------------------------*/

INT histo_filling(char*);
INT histo_booking(void);

ANA_MODULE histo_module = {
  "General histo",               /* module name           */  
  "Stefan Ritt",                 /* author                */
  histo_filling,                 /* event routine         */
  NULL,                          /* BOR routine           */
  NULL,                          /* EOR routine           */
  histo_booking,                 /* init routine          */
  NULL,                          /* exit routine          */
  NULL,                          /* parameter structure   */
  0,                             /* structure size        */
  NULL,                          /* initial parameters    */
};

/*-- init routine --------------------------------------------------*/

INT histo_booking(void)
{
  int i;

  /* -- Plastic Veto Product Histograms. --*/
  HBOOK1(10048, "PV prod 48, Prod gt 0, CsI gt 800", 500, 0.f, 2000.f, 0.f); 
  HBOOK1(10049, "PV prod 49, Prod gt 0, CsI gt 800", 500, 0.f, 2000.f, 0.f); 
  HBOOK1(10050, "PV prod 50, Prod gt 0, CsI gt 800", 500, 0.f, 2000.f, 0.f); 
  HBOOK1(10051, "PV prod 51, Prod gt 0, CsI gt 800", 500, 0.f, 2000.f, 0.f); 
  HBOOK1(10052, "pv prod 52, Prod gt 0, CsI gt 800", 500, 0.f, 2000.f, 0.f);
  HBOOK1(10053, "pv prod 53, prod gt 0, CsI gt 800", 500, 0.f, 2000.f, 0.f);
  HBOOK1(10054, "pv prod 54, prod gt 0, CsI gt 800", 500, 0.f, 2000.f, 0.f);
  HBOOK1(10055, "pv prod 55, prod gt 0, CsI gt 800", 500, 0.f, 2000.f, 0.f);

  HBOOK1(11048, "PVGM0, PVGM0 gt 0, CsI in strip gt 800", 500, 0.f, 2000.f, 0.f); 
  HBOOK1(11049, "PVGM1, PVGM1 gt 0, CsI in strip gt 800", 500, 0.f, 2000.f, 0.f); 
  HBOOK1(11050, "PVGM2, PVGM2 gt 0, CsI in strip gt 800", 500, 0.f, 2000.f, 0.f); 
  HBOOK1(11051, "PVGM3, PVGM3 gt 0, CsI in strip gt 800", 500, 0.f, 2000.f, 0.f); 
  HBOOK1(11052, "PVGM4, PVGM4 gt 0, CsI in strip gt 800", 500, 0.f, 2000.f, 0.f);
  HBOOK1(11053, "PVGM5, PVGM5 gt 0, CsI in strip gt 800", 500, 0.f, 2000.f, 0.f);
  HBOOK1(11054, "PVGM6, PVGM6 gt 0, CsI in strip gt 800", 500, 0.f, 2000.f, 0.f);
  HBOOK1(11055, "PVGM7, PVGM7 gt 0, CsI in strip gt 800", 500, 0.f, 2000.f, 0.f);

  /* -- Plastic Veto Meantime Histograms. --*/
  HBOOK1(12048, "PV 0 meantime", 200, 0.f, 200.f, 0.f); 
  HBOOK1(12049, "PV 1 meantime", 200, 0.f, 200.f, 0.f); 
  HBOOK1(12050, "PV 2 meantime", 200, 0.f, 200.f, 0.f); 
  HBOOK1(12051, "PV 3 meantime", 200, 0.f, 200.f, 0.f); 
  HBOOK1(12052, "pv 4 meantime", 200, 0.f, 200.f, 0.f);
  HBOOK1(12053, "pv 5 meantime", 200, 0.f, 200.f, 0.f);
  HBOOK1(12054, "pv 6 meantime", 200, 0.f, 200.f, 0.f);
  HBOOK1(12055, "pv 7 meantime", 200, 0.f, 200.f, 0.f);

  /* looking for the CsI crystals opposite to the NaI crystals */
  HBOOK1(17018, "Max CsI Hit with 83 MeV When NaI098 Max and 55 MeV", 44, -0.5f, 43.5f, 0.f);
  HBOOK2(18018, "Theta and Phi of Max CsI Hit When NaI098 Max and 53 MeV",
                 160, 100.f, 260.f,80, 20.f, 100.f, 0.f);
  HBOOK1(17019, "Max CsI Hit with 83 MeV When NaI099 Max and 55 MeV", 44, -0.5f, 43.5f, 0.f);
  HBOOK2(18019, "Theta and Phi of Max CsI Hit When NaI099 Max and 53 MeV",
                 160, 100.f, 260.f,80, 20.f, 100.f, 0.f);
  HBOOK1(17020, "Max CsI Hit with 83 MeV When NaI100 Max and 55 MeV", 44, -0.5f, 43.5f, 0.f);
  HBOOK2(18020, "Theta and Phi of Max CsI Hit When NaI100 Max and 53 MeV",
                 160, 100.f, 260.f,80, 20.f, 100.f, 0.f);
  HBOOK1(17021, "Max CsI Hit with 83 MeV When NaI101 Max and 55 MeV", 44, -0.5f, 43.5f, 0.f);
  HBOOK2(18021, "Theta and Phi of Max CsI Hit When NaI101 Max and 53 MeV",
                 160, 100.f, 260.f,80, 20.f, 100.f, 0.f);
  HBOOK1(17022, "Max CsI Hit with 83 MeV When NaI102 Max and 55 MeV", 44, -0.5f, 43.5f, 0.f);
  HBOOK2(18022, "Theta and Phi of Max CsI Hit When NaI102 Max and 53 MeV",
                 160, 100.f, 260.f,80, 20.f, 100.f, 0.f);
  HBOOK1(17023, "Max CsI Hit with 83 MeV When NaI103 Max and 55 MeV", 44, -0.5f, 43.5f, 0.f);
  HBOOK2(18023, "Theta and Phi of Max CsI Hit When NaI103 Max and 53 MeV",
                 160, 100.f, 260.f,80, 20.f, 100.f, 0.f);

  for (i=0; i<44; i++)
    HBOOK2(19000+i,"thit vs. cadc",240,200.f,2000.f,40,85.f,105.f,0.f);
   
  return SUCCESS;
}
                                 
/*-- event routine -------------------------------------------------*/
                                                                                       

INT histo_filling(char *pevent)
{
int          i,m,j; 
float        *cadc, *thit;
WORD         *trig;
ASUM_BANK    *asum;
PV___BANK	   *pv__;
ANG2_BANK    *ang2;

int *c,pvxtals[][8]={{4,0,9,19,28},{4,1,10,20,29},
							{5,2,12,21,30,36},{5,3,13,22,30,37},
							{5,5,14,24,32,37},{5,6,15,25,33,38},
							{5,7,17,26,33,39},{4,8,18,27,34}};

int make_or=0;
BOOL e_in_pv[8]={0,0,0,0,0,0,0,0},e_in_pvOR,beam_bar,exist_max,cut_rf;
double pv_prod_high[8]={400.,400.,400.,400.,400.,400.,400.,450.};
double pv_prod_low[8]={100.,100.,125.,125.,125.,125.,125.,75.};
e_in_pvOR=beam_bar=cut_rf=exist_max=0;

   /* open banks of interest */
  if (bk_locate(pevent, "CADC", &cadc) == 0 ||
      bk_locate(pevent, "THIT", &thit) == 0 ||
      bk_locate(pevent, "PV__", &pv__) == 0 ||
      bk_locate(pevent, "ASUM", &asum) == 0 ||
      bk_locate(pevent, "TRIG", &trig) == 0 ||
      bk_locate(pevent, "ANG2", &ang2) == 0)
    return 1;
  
 /*Name cuts and define them*/

 for (i=0;i<8;i++)
   {
   if (cadc[48+i]*cadc[48+8+i]>0)
      e_in_pv[i]=((sqrt(cadc[48+i]*cadc[48+8+i])>pv_prod_low[i]) && 
              (sqrt(cadc[48+i]*cadc[48+8+i])<pv_prod_high[i]));
   else e_in_pv[i]=0;
   }
 for (i=0;i<8;i++) 
   make_or += (int) e_in_pv[i];
 e_in_pvOR=(make_or>0);
 cut_rf=((thit[74] < 99) || ( thit[74] > 102));
 beam_bar=(thit[73]<90.5);
 exist_max=(asum->csi_max>=0);

 /*--Fill plastic veto product histos.--*/

	/*cut on CsI strip*/
	for(j=0;j<8;j++){
		c=pvxtals[j];
		for(i=1;i<=c[0];i++)
			if(cadc[c[i]]>800)
				if(pv__->pvgm[j]>20)
					HF1(11000+48+j,(float)pv__->pvgm[j], 1.f);
 
  }


	/*cut on single CsI */

  for (i=0; i<=3; i++)
    {
     m=i+19;
     if (cadc[48+i]*cadc[48+8+i] > 0.)
       if (cadc[m] > 800.)
         HF1(10000+48+i, (float) sqrt(cadc[48+i]*cadc[48+8+i]), 1.f);
    }

  for (i=4; i<=7; i++)
    {
    m=i+20;
    if (cadc[48+i]*cadc[48+8+i] > 0.)
      if (cadc[m] > 800.)
        HF1(10000+48+i, (float) sqrt(cadc[48+i]*cadc[48+8+i]), 1.f);
    } 

 
  /*fill Plastic Veto Meantime */
 
  for (i=0; i<=7; i++)
    {
    if (thit[48+i]+thit[48+8+i] > 0)
      HF1(12000+48+i, (float) ((thit[48+i]+thit[48+8+i])/2.0), 1.f);
    }
 
  /* looking for the CsI crystals opposite to the NaI crystals */
  if (asum->nai_sum < 1190 && asum->csi_sum > 1910)
    for (i=18 ; i<=23 ; i++)
      if(asum->nai_max == i)
        {
        HF1(17000+i, (float) asum->csi_max , 1.f);
        HF2(18000+i, ang2->csi_phi, ang2->csi_theta, 1.f);
        }

 
  for (i=0; i<44; i++)
    HF2(19000+i, (float) cadc[i], (float) thit[i], 1.f);
  
  

  
  return SUCCESS;
}

