/********************************************************************\

  Name:         dave.c
  Created by:   Stefan Ritt

  Contents:     PiBeta Analyzer module for <template>


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  <date>       <XX>  created
  7-13-97     Dave L. Target calibration coding


\********************************************************************/
                                                        
/*-- Include files -------------------------------------------------*/

/* standard includes */
#include <stdio.h>
#include <math.h>

/* midas includes */
#include "midas.h"
#include "hardware.h"
#include "event.h"

/*-- Parameters ----------------------------------------------------*/


/* define some global pointers to save many "ctgt_param->"s */

/*-- Static parameters ---------------------------------------------*/


/*-- Module declaration --------------------------------------------*/

INT pv__er(char*);
INT pv___init(void);

ANA_MODULE pv___module = {
  "pv__",                        /* module name           */  
  "David Lawrence",              /* author                */
  pv__er,                          /* event routine         */
  NULL,                          /* BOR routine           */
  NULL,                          /* EOR routine           */
  pv___init,                          /* init routine           */
  NULL,                          /* exit routine           */
  NULL,                          /* parameter structure   */
  0,                             /* structure size        */
  NULL,                          /* initial parameters    */
  1	                             /* enabled flag          */
};


/*-- init routine -------------------------------------------------*/
INT pv___init(void)
{
  printf("Plastic veto module initialized.\n");
  return SUCCESS;
}


/*-- event routine -------------------------------------------------*/

INT pv__er(char *pevent)
{
int          i,n;
float        *cadc,*thit;
float        a,max=(float)0.0;
PV___BANK    *pv__;

  /* look for CADC bank, return if not present */
  n = bk_locate(pevent, "CADC", &cadc);
  if (n == 0)return SUCCESS;
  /* look for THIT bank, return if not present */
  n = bk_locate(pevent, "THIT", &thit);
  if (n == 0)return SUCCESS;

  /* create calculated bank */
  bk_create(pevent, "PV__", TID_STRUCT, &pv__);

  /*---- perform calculations --------------------------------------*/
	
  /* plastic veto geometric mean */
	for(i=0;i<8;i++){
		a=cadc[48+i]*cadc[48+i+8];
		pv__->pvgm[i]=sqrt(fabs(a));
		if(pv__->pvgm[i]>max)max=(float)pv__->pvgm[i];
	}
	pv__->max_pvgm=max;

  /* plastic veto mean time */
  for (i=0 ; i<8 ; i++)
    {
    if (thit[48+i]>0 && thit[48+i+8]>0)
      pv__->pvmt[i] = (thit[48+i]+thit[48+i+8])/2.0;
    else
      pv__->pvmt[i] = 0;
    }
  
  /*---- close calculated bank -------------------------------------*/
  bk_close(pevent, pv__+1);
  
  return SUCCESS;
}












