/********************************************************************\

  Name:         tdccalib.c
  Created by:   Stefan Ritt

  Contents:     PiBeta Analyzer module for TDC calibration


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  04-JUL-97    SR    created

\********************************************************************/
                                                        
/*-- Include files -------------------------------------------------*/

/* standard includes */
#include <stdio.h>
#include "util.h"

/* midas includes */
#include "midas.h"
#include "hardware.h"
#include "event.h"
#include "analyzer.h"

/* cernlib includes */
#ifdef OS_WINNT
#define VISUAL_CPLUSPLUS
#endif

#ifdef __linux__
#define f2cFortran
#endif

#include <cfortran.h>
#include <hbook.h>

/*-- Parameters ----------------------------------------------------*/


/*-- Hardware parameters -------------------------------------------*/

typedef struct {
  int slot;
  int n_channels;
} CHANNEL_MAP;

CHANNEL_MAP tdc_map[] = {
  { 10, 80 },
  {  9, 80 },
  {  0  }
};

/*-- Module declaration --------------------------------------------*/

INT tdc_calib(char*);
INT tdc_calib_init(void);
INT tdc_calib_bor(INT run_number);

ANA_MODULE tdc_calib_module = {
  "TDC calibration",             /* module name           */  
  "Stefan Ritt",                 /* author                */
  tdc_calib,                     /* event routine         */
  NULL,                          /* BOR routine           */
  NULL,                          /* EOR routine           */
  tdc_calib_init,                /* init routine          */
  NULL,                          /* exit routine          */
  NULL,                          /* parameter structure   */
  0,                             /* structure size        */
  NULL,                          /* initial parameters    */
};

/*-- init routine --------------------------------------------------*/

#define TDC_N_BINS   300
#define TDC_X_LOW      0
#define TDC_X_HIGH   300

INT tdc_calib_init(void)
{
int  i;
char str[80];

  /* tdc hit histos */
  for (i=0; i<N_TDC; i++)
    {
    sprintf(str, "TDC%02d", i);
    HBOOK1(TDCCALIB_ID_BASE+i, str, TDC_N_BINS, TDC_X_LOW.f, TDC_X_HIGH.f, 0.f); 
    }

  return SUCCESS;
}

/*-- event routine -------------------------------------------------*/

INT tdc_calib(char *pevent)
{
INT          i, j, channel, n_data;
LRS1877_DATA *lrs1877;
float        tdc_hit[N_TDC];
float        *thit;

  /* look for LTDC bank, return if not present */
  n_data = bk_locate(pevent, "LTDC", &lrs1877);
  if (n_data == 0)
    return 1;

  /*
  lrs1877++; // skip header
  n_data--;
  */

  /*---- TDC decoding ----------------------------------------------*/

  /* init tdc channels to 10000 (overflow) */
  for (i=0 ; i<N_TDC ; i++)
    tdc_hit[i] = 10000.f;

  for (i=0 ; i<n_data ; i++)
    {
    for (j=0,channel=0 ; 
         tdc_map[j].slot > 0 && lrs1877[i].geo_addr != tdc_map[j].slot ; 
         j++)
      channel += tdc_map[j].n_channels;
    channel += lrs1877[i].channel;

    /* find smallest value (first hit leading edge) */
    if (channel < N_TDC && lrs1877[i].edge == 0) 
      if (lrs1877[i].data * 0.5 < tdc_hit[channel])
        tdc_hit[channel] = (float) (lrs1877[i].data * 0.5);
    }

  /*---- create banks ----------------------------------------------*/
  
  bk_create(pevent, "THIT", TID_FLOAT, &thit);
  for (i=0 ; i<N_TDC ; i++)
    if (tdc_hit[i] == 10000)
      *thit++ = 0.f;
    else
      *thit++ = tdc_hit[i];

  bk_close(pevent, thit);
  
  /* fill histos */
  for (i=0 ; i<N_TDC ; i++)
    if (tdc_hit[i] != 10000)
      HF1(TDCCALIB_ID_BASE+i, tdc_hit[i], 1.f);

  return SUCCESS;
}

