/********************************************************************\

  Name:         event.h
  Created by:   ODBedit program

  Contents:     This file contains C structures for the "Runinfo"
                tree in the ODB and the "/Analyzer/Parameters" tree.

                Additionally, it contains the "Settings" subtree for
                all items listed under "/Equipment" as well as their
                event definition.

                It can be used by the frontend and analyzer to work
                with these information.

                All C structures are accompanied with a string represen-
                tation which can be used in the db_create_record function
                to setup an ODB structure which matches the C structure.

  Created on:   Thu Aug 14 08:13:24 1997

\********************************************************************/

typedef struct {
  INT       state;
  INT       online_mode;
  INT       run_number;
  char      start_time[32];
  INT       transition_in_progress;
} RUNINFO;

#define RUNINFO_STR(_name) char *_name[] = {\
"[.]",\
"State = INT : 3",\
"Online Mode = INT : 1",\
"Run number = INT : 374",\
"Start time = STRING : [32] Thu Aug 14 07:19:51 1997",\
"Transition in progress = INT : 0",\
"",\
NULL }

typedef struct {
  INT       run_mode;
  float     theta_swing;
  float     phi_swing;
  char      comment[80];
} EXP_PARAM;

#define EXP_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"Run mode = INT : 1",\
"Theta Swing = FLOAT : 63.4",\
"Phi Swing = FLOAT : 0",\
"Comment = STRING : [80] Two Arm or One Arm Pi0n or Pig Trigger, Position 2",\
"",\
NULL }

#ifndef EXCL_GLOBAL

typedef struct {
  float     adc_threshold;
} GLOBAL_PARAM;

#define GLOBAL_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"ADC Threshold = FLOAT : 5",\
"",\
NULL }

#endif

#ifndef EXCL_ADC_CALIBRATION

typedef struct {
  INT       pedestal[144];
  float     software_gain[144];
  float     software_gain_errors[144];
  float     histo_threshold;
} ADC_CALIBRATION_PARAM;

#define ADC_CALIBRATION_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"Pedestal = INT[144] :",\
"[0] 174",\
"[1] 194",\
"[2] 176",\
"[3] 182",\
"[4] 185",\
"[5] 215",\
"[6] 202",\
"[7] 202",\
"[8] 200",\
"[9] 200",\
"[10] 173",\
"[11] 178",\
"[12] 177",\
"[13] 199",\
"[14] 174",\
"[15] 188",\
"[16] 217",\
"[17] 228",\
"[18] 199",\
"[19] 185",\
"[20] 180",\
"[21] 206",\
"[22] 180",\
"[23] 181",\
"[24] 175",\
"[25] 206",\
"[26] 205",\
"[27] 213",\
"[28] 184",\
"[29] 200",\
"[30] 186",\
"[31] 185",\
"[32] 197",\
"[33] 228",\
"[34] 220",\
"[35] 197",\
"[36] 195",\
"[37] 221",\
"[38] 212",\
"[39] 217",\
"[40] 216",\
"[41] 231",\
"[42] 212",\
"[43] 220",\
"[44] 162",\
"[45] 177",\
"[46] 147",\
"[47] 155",\
"[48] 219",\
"[49] 242",\
"[50] 227",\
"[51] 227",\
"[52] 210",\
"[53] 235",\
"[54] 214",\
"[55] 223",\
"[56] 215",\
"[57] 237",\
"[58] 214",\
"[59] 217",\
"[60] 213",\
"[61] 232",\
"[62] 214",\
"[63] 210",\
"[64] 183",\
"[65] 195",\
"[66] 177",\
"[67] 172",\
"[68] 193",\
"[69] 213",\
"[70] 193",\
"[71] 210",\
"[72] 185",\
"[73] 177",\
"[74] 143",\
"[75] 153",\
"[76] 150",\
"[77] 166",\
"[78] 149",\
"[79] 154",\
"[80] 256",\
"[81] 310",\
"[82] 226",\
"[83] 281",\
"[84] 223",\
"[85] 288",\
"[86] 244",\
"[87] 227",\
"[88] 239",\
"[89] 279",\
"[90] 261",\
"[91] 239",\
"[92] 227",\
"[93] 289",\
"[94] 241",\
"[95] 251",\
"[96] 305",\
"[97] 349",\
"[98] 292",\
"[99] 303",\
"[100] 280",\
"[101] 315",\
"[102] 261",\
"[103] 270",\
"[104] 298",\
"[105] 323",\
"[106] 275",\
"[107] 276",\
"[108] 171",\
"[109] 290",\
"[110] 264",\
"[111] 265",\
"[112] 252",\
"[113] 242",\
"[114] 234",\
"[115] 252",\
"[116] 273",\
"[117] 313",\
"[118] 272",\
"[119] 270",\
"[120] 243",\
"[121] 285",\
"[122] 241",\
"[123] 253",\
"[124] 269",\
"[125] 298",\
"[126] 247",\
"[127] 280",\
"[128] 193",\
"[129] 227",\
"[130] 219",\
"[131] 219",\
"[132] 342",\
"[133] 222",\
"[134] 216",\
"[135] 215",\
"[136] 208",\
"[137] 244",\
"[138] 221",\
"[139] 223",\
"[140] 222",\
"[141] 251",\
"[142] 211",\
"[143] 221",\
"Software Gain = FLOAT[144] :",\
"[0] 1",\
"[1] 1",\
"[2] 1",\
"[3] 1",\
"[4] 1",\
"[5] 1",\
"[6] 1",\
"[7] 1",\
"[8] 1",\
"[9] 1",\
"[10] 1",\
"[11] 1",\
"[12] 1",\
"[13] 1",\
"[14] 1",\
"[15] 1",\
"[16] 1",\
"[17] 1",\
"[18] 1",\
"[19] 1",\
"[20] 1",\
"[21] 1",\
"[22] 1",\
"[23] 1",\
"[24] 1",\
"[25] 1",\
"[26] 1",\
"[27] 1",\
"[28] 1",\
"[29] 1",\
"[30] 1",\
"[31] 1",\
"[32] 1",\
"[33] 1",\
"[34] 1",\
"[35] 1",\
"[36] 1",\
"[37] 1",\
"[38] 1",\
"[39] 1",\
"[40] 1",\
"[41] 1",\
"[42] 1",\
"[43] 1",\
"[44] 1",\
"[45] 1",\
"[46] 1",\
"[47] 1",\
"[48] 1",\
"[49] 1",\
"[50] 1",\
"[51] 1",\
"[52] 1",\
"[53] 1",\
"[54] 1",\
"[55] 1",\
"[56] 1",\
"[57] 1",\
"[58] 1",\
"[59] 1",\
"[60] 1",\
"[61] 1",\
"[62] 1",\
"[63] 1",\
"[64] 1",\
"[65] 1",\
"[66] 1",\
"[67] 1",\
"[68] 1",\
"[69] 1",\
"[70] 1",\
"[71] 1",\
"[72] 1",\
"[73] 1",\
"[74] 1",\
"[75] 1",\
"[76] 1",\
"[77] 1",\
"[78] 1",\
"[79] 1",\
"[80] 1",\
"[81] 1",\
"[82] 1",\
"[83] 1",\
"[84] 1",\
"[85] 1",\
"[86] 1",\
"[87] 1",\
"[88] 1",\
"[89] 1",\
"[90] 1",\
"[91] 1",\
"[92] 1",\
"[93] 1",\
"[94] 1",\
"[95] 1",\
"[96] 1",\
"[97] 1",\
"[98] 1",\
"[99] 1",\
"[100] 1",\
"[101] 1",\
"[102] 1",\
"[103] 1",\
"[104] 1",\
"[105] 1",\
"[106] 1",\
"[107] 1",\
"[108] 1",\
"[109] 1",\
"[110] 1",\
"[111] 1",\
"[112] 1",\
"[113] 1",\
"[114] 1",\
"[115] 1",\
"[116] 1",\
"[117] 1",\
"[118] 1",\
"[119] 1",\
"[120] 1",\
"[121] 1",\
"[122] 1",\
"[123] 1",\
"[124] 1",\
"[125] 1",\
"[126] 1",\
"[127] 1",\
"[128] 1",\
"[129] 1",\
"[130] 1",\
"[131] 1",\
"[132] 1",\
"[133] 1",\
"[134] 1",\
"[135] 1",\
"[136] 1",\
"[137] 1",\
"[138] 1",\
"[139] 1",\
"[140] 1",\
"[141] 1",\
"[142] 1",\
"[143] 1",\
"Software Gain Errors = FLOAT[144] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"[4] 0",\
"[5] 0",\
"[6] 0",\
"[7] 0",\
"[8] 0",\
"[9] 0",\
"[10] 0",\
"[11] 0",\
"[12] 0",\
"[13] 0",\
"[14] 0",\
"[15] 0",\
"[16] 0",\
"[17] 0",\
"[18] 0",\
"[19] 0",\
"[20] 0",\
"[21] 0",\
"[22] 0",\
"[23] 0",\
"[24] 0",\
"[25] 0",\
"[26] 0",\
"[27] 0",\
"[28] 0",\
"[29] 0",\
"[30] 0",\
"[31] 0",\
"[32] 0",\
"[33] 0",\
"[34] 0",\
"[35] 0",\
"[36] 0",\
"[37] 0",\
"[38] 0",\
"[39] 0",\
"[40] 0",\
"[41] 0",\
"[42] 0",\
"[43] 0",\
"[44] 0",\
"[45] 0",\
"[46] 0",\
"[47] 0",\
"[48] 0",\
"[49] 0",\
"[50] 0",\
"[51] 0",\
"[52] 0",\
"[53] 0",\
"[54] 0",\
"[55] 0",\
"[56] 0",\
"[57] 0",\
"[58] 0",\
"[59] 0",\
"[60] 0",\
"[61] 0",\
"[62] 0",\
"[63] 0",\
"[64] 0",\
"[65] 0",\
"[66] 0",\
"[67] 0",\
"[68] 0",\
"[69] 0",\
"[70] 0",\
"[71] 0",\
"[72] 0",\
"[73] 0",\
"[74] 0",\
"[75] 0",\
"[76] 0",\
"[77] 0",\
"[78] 0",\
"[79] 0",\
"[80] 0",\
"[81] 0",\
"[82] 0",\
"[83] 0",\
"[84] 0",\
"[85] 0",\
"[86] 0",\
"[87] 0",\
"[88] 0",\
"[89] 0",\
"[90] 0",\
"[91] 0",\
"[92] 0",\
"[93] 0",\
"[94] 0",\
"[95] 0",\
"[96] 0",\
"[97] 0",\
"[98] 0",\
"[99] 0",\
"[100] 0",\
"[101] 0",\
"[102] 0",\
"[103] 0",\
"[104] 0",\
"[105] 0",\
"[106] 0",\
"[107] 0",\
"[108] 0",\
"[109] 0",\
"[110] 0",\
"[111] 0",\
"[112] 0",\
"[113] 0",\
"[114] 0",\
"[115] 0",\
"[116] 0",\
"[117] 0",\
"[118] 0",\
"[119] 0",\
"[120] 0",\
"[121] 0",\
"[122] 0",\
"[123] 0",\
"[124] 0",\
"[125] 0",\
"[126] 0",\
"[127] 0",\
"[128] 0",\
"[129] 0",\
"[130] 0",\
"[131] 0",\
"[132] 0",\
"[133] 0",\
"[134] 0",\
"[135] 0",\
"[136] 0",\
"[137] 0",\
"[138] 0",\
"[139] 0",\
"[140] 0",\
"[141] 0",\
"[142] 0",\
"[143] 0",\
"Histo threshold = FLOAT : 20",\
"",\
NULL }

#endif

#ifndef EXCL_MWPC_CALIBRATION

typedef struct {
  float     distance_a_b;
  float     distance_b_target;
} MWPC_CALIBRATION_PARAM;

#define MWPC_CALIBRATION_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"Distance A-B = FLOAT : 507",\
"Distance B-Target = FLOAT : 643",\
"",\
NULL }

#endif

#ifndef EXCL_ADC_SUMMING

typedef struct {
  float     adc_threshold;
} ADC_SUMMING_PARAM;

#define ADC_SUMMING_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"ADC threshold = FLOAT : 5",\
"",\
NULL }

#endif

#ifndef EXCL_ANGLE

typedef struct {
  float     alpha;
} ANGLE_PARAM;

#define ANGLE_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"Alpha = FLOAT : 0.72",\
"",\
NULL }

#endif

#ifndef EXCL_CTGT

typedef struct {
  double    a;
  double    b;
  double    c;
  double    d;
  double    e;
  double    f;
  double    g;
  double    cutoff;
  double    cfac;
} CTGT_PARAM;

#define CTGT_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"A = DOUBLE : 0.78263",\
"B = DOUBLE : 4.30098",\
"C = DOUBLE : 123.172",\
"D = DOUBLE : 2779.93",\
"E = DOUBLE : 11.4239",\
"F = DOUBLE : -0.302883",\
"G = DOUBLE : 0.00207466",\
"cutoff = DOUBLE : 74",\
"cfac = DOUBLE : 0.66",\
"",\
NULL }

#endif

#ifndef EXCL_ANGLE2

typedef struct {
  double    alpha;
} ANGLE2_PARAM;

#define ANGLE2_PARAM_STR(_name) char *_name[] = {\
"[.]",\
"alpha = DOUBLE : 0.7",\
"",\
NULL }

#endif

#ifndef EXCL_TRIGGER

typedef struct {
  float     xa;
  float     ya;
  float     xb;
  float     yb;
  float     xtgt;
  float     ytgt;
} MWPC_BANK;

#define MWPC_BANK_STR(_name) char *_name[] = {\
"[.]",\
"xa = FLOAT : -41.4",\
"ya = FLOAT : 2.2",\
"xb = FLOAT : -34.4",\
"yb = FLOAT : -3.6",\
"xtgt = FLOAT : -25.5223",\
"ytgt = FLOAT : -10.9558",\
"",\
NULL }

typedef struct {
  float     csi_sum;
  INT       csi_hit;
  INT       csi_max;
  float     csi_inner_sum;
  float     csi_outer_sum;
  float     nai_sum;
  INT       nai_max;
  float     nai_inner_sum;
  float     nai_outer_sum;
} ASUM_BANK;

#define ASUM_BANK_STR(_name) char *_name[] = {\
"[.]",\
"CsI sum = FLOAT : 119.773",\
"CsI hit = INT : 3",\
"CsI max = INT : 11",\
"CsI inner sum = FLOAT : 119.773",\
"CsI outer sum = FLOAT : 0",\
"NaI sum = FLOAT : 3108.69",\
"NaI max = INT : 23",\
"NaI inner sum = FLOAT : 3030.97",\
"NaI outer sum = FLOAT : 77.72",\
"",\
NULL }

typedef struct {
  double    pvgm[8];
  double    max_pvgm;
  double    pvmt[8];
} PV___BANK;

#define PV___BANK_STR(_name) char *_name[] = {\
"[.]",\
"pvgm = DOUBLE[8] :",\
"[0] 0.125",\
"[1] 1.36359",\
"[2] 0.992157",\
"[3] 0.875",\
"[4] 1.45237",\
"[5] 0.125",\
"[6] 0.992157",\
"[7] 0.992157",\
"max_pvgm = DOUBLE : 1.45237",\
"pvmt = DOUBLE[8] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"[4] 0",\
"[5] 0",\
"[6] 0",\
"[7] 0",\
"",\
NULL }

typedef struct {
  double    edge_func;
  double    sumtgt;
  double    e__in_tgt;
} CTGT_BANK;

#define CTGT_BANK_STR(_name) char *_name[] = {\
"[.]",\
"edge_func = DOUBLE : -10.432",\
"sumtgt = DOUBLE : 1593.33",\
"e+ in tgt = DOUBLE : 0",\
"",\
NULL }

typedef struct {
  float     csi_phi;
  float     csi_theta;
  float     nai_phi;
  float     nai_theta;
  float     rel_ang;
} ANG2_BANK;

#define ANG2_BANK_STR(_name) char *_name[] = {\
"[.]",\
"CsI phi = FLOAT : 173.727",\
"CsI theta = FLOAT : 172.755",\
"NaI phi = FLOAT : 360",\
"NaI theta = FLOAT : 90",\
"rel_ang = FLOAT : 97.2011",\
"",\
NULL }

typedef struct {
  struct {
    WORD      slot[12];
    WORD      plane[12];
    float     threshold[12];
    WORD      delay[12];
    WORD      n_wires[4];
    float     wire_spacing[4];
    BOOL      mirror[4];
  } pcos;
  INT       ps7106_threshold;
  WORD      lrs_2365_coeff[18];
  BYTE      io506;
  INT       lrs_4518_1[16];
  INT       lrs_4518_2[16];
  float     da500_hi;
  float     da500_lo;
} TRIGGER_SETTINGS;

#define TRIGGER_SETTINGS_STR(_name) char *_name[] = {\
"[PCOS]",\
"Slot = WORD[12] :",\
"[0] 4",\
"[1] 5",\
"[2] 6",\
"[3] 7",\
"[4] 8",\
"[5] 9",\
"[6] 10",\
"[7] 11",\
"[8] 13",\
"[9] 14",\
"[10] 15",\
"[11] 16",\
"Plane = WORD[12] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"[4] 1",\
"[5] 1",\
"[6] 1",\
"[7] 1",\
"[8] 2",\
"[9] 2",\
"[10] 3",\
"[11] 3",\
"Threshold = FLOAT[12] :",\
"[0] 4",\
"[1] 4",\
"[2] 4",\
"[3] 4",\
"[4] 4",\
"[5] 4",\
"[6] 4",\
"[7] 4",\
"[8] 4",\
"[9] 4",\
"[10] 4",\
"[11] 4",\
"Delay = WORD[12] :",\
"[0] 400",\
"[1] 400",\
"[2] 400",\
"[3] 400",\
"[4] 400",\
"[5] 400",\
"[6] 400",\
"[7] 400",\
"[8] 400",\
"[9] 400",\
"[10] 400",\
"[11] 400",\
"N wires = WORD[4] :",\
"[0] 128",\
"[1] 128",\
"[2] 64",\
"[3] 64",\
"Wire spacing = FLOAT[4] :",\
"[0] 2",\
"[1] 2",\
"[2] 2",\
"[3] 2",\
"Mirror = BOOL[4] :",\
"[0] 0",\
"[1] 1",\
"[2] 0",\
"[3] 0",\
"",\
"[.]",\
"PS7106 Threshold = INT : 20",\
"LRS 2365 Coeff = WORD[18] :",\
"[0] 24",\
"[1] 1029",\
"[2] 24",\
"[3] 16388",\
"[4] 0",\
"[5] 16385",\
"[6] 0",\
"[7] 1028",\
"[8] 0",\
"[9] 1032",\
"[10] 24",\
"[11] 1028",\
"[12] 0",\
"[13] 1025",\
"[14] 0",\
"[15] 32768",\
"[16] 255",\
"[17] 0",\
"IO506 = BYTE : 7",\
"LRS 4518 1 = INT[16] :",\
"[0] 28",\
"[1] 28",\
"[2] 16",\
"[3] 2",\
"[4] 0",\
"[5] 14",\
"[6] 16",\
"[7] 8",\
"[8] 8",\
"[9] 8",\
"[10] 4",\
"[11] 18",\
"[12] 6",\
"[13] 12",\
"[14] 8",\
"[15] 0",\
"LRS 4518 2 = INT[16] :",\
"[0] 24",\
"[1] 24",\
"[2] 24",\
"[3] 24",\
"[4] 24",\
"[5] 24",\
"[6] 24",\
"[7] 24",\
"[8] 24",\
"[9] 24",\
"[10] 24",\
"[11] 24",\
"[12] 24",\
"[13] 24",\
"[14] 24",\
"[15] 24",\
"DA500 Hi = FLOAT : 0.2",\
"DA500 Lo = FLOAT : 0.15",\
"",\
NULL }

#endif

#ifndef EXCL_SCALER

typedef struct {
  double    trigger;
  double    trigger_accepted;
  double    mhc;
  double    b0;
  double    b1;
  double    b0_b1;
  double    csi_hi;
  double    csi_lo;
  double    nai_inner_hi;
  double    nai_inner_lo;
  double    nai_outer_hi;
  double    nai_outer_lo;
} RTES_BANK;

#define RTES_BANK_STR(_name) char *_name[] = {\
"[.]",\
"Trigger = DOUBLE : 392.4",\
"Trigger accepted = DOUBLE : 177",\
"MHC = DOUBLE : 1.3",\
"B0 = DOUBLE : 321693",\
"B1 = DOUBLE : 122633",\
"B0*B1 = DOUBLE : 82936.5",\
"CsI hi = DOUBLE : 5246.1",\
"CsI lo = DOUBLE : 7143.3",\
"NaI inner hi = DOUBLE : 956.5",\
"NaI inner lo = DOUBLE : 1616.8",\
"NaI outer hi = DOUBLE : 911.9",\
"NaI outer lo = DOUBLE : 2690.1",\
"",\
NULL }

typedef struct {
  WORD      scaler0_slot;
  WORD      first_channel;
  WORD      last_channel;
} SCALER_SETTINGS;

#define SCALER_SETTINGS_STR(_name) char *_name[] = {\
"[.]",\
"Scaler0 slot = WORD : 10",\
"First channel = WORD : 0",\
"Last channel = WORD : 1",\
"",\
NULL }

#endif

#ifndef EXCL_HV

typedef struct {
  float     demand[144];
  float     measured[144];
  float     current[144];
} HV_EVENT;

#define HV_EVENT_STR(_name) char *_name[] = {\
"[.]",\
"Demand = FLOAT[144] :",\
"[0] 2051",\
"[1] 1783",\
"[2] 1885",\
"[3] 1602",\
"[4] 1459",\
"[5] 1452",\
"[6] 1639",\
"[7] 1619",\
"[8] 1802",\
"[9] 1544",\
"[10] 1814",\
"[11] 1968",\
"[12] 1823",\
"[13] 1764",\
"[14] 1326",\
"[15] 1834",\
"[16] 1730",\
"[17] 1523",\
"[18] 1616",\
"[19] 1560",\
"[20] 1790",\
"[21] 1728",\
"[22] 1521",\
"[23] 1688",\
"[24] 1709",\
"[25] 1756",\
"[26] 1847",\
"[27] 1535",\
"[28] 1360",\
"[29] 1759",\
"[30] 1922",\
"[31] 1919",\
"[32] 1374",\
"[33] 1972",\
"[34] 1411",\
"[35] 1553",\
"[36] 1440",\
"[37] 1379",\
"[38] 1394",\
"[39] 1469",\
"[40] 1907",\
"[41] 1522",\
"[42] 1644",\
"[43] 1711",\
"[44] 2200",\
"[45] 2000",\
"[46] 0",\
"[47] 0",\
"[48] 1456",\
"[49] 1542",\
"[50] 1534",\
"[51] 1364",\
"[52] 1401",\
"[53] 1203",\
"[54] 1338",\
"[55] 1528",\
"[56] 1265",\
"[57] 1360",\
"[58] 1251",\
"[59] 1242",\
"[60] 1279",\
"[61] 1509",\
"[62] 1221",\
"[63] 1401",\
"[64] 0",\
"[65] 0",\
"[66] 0",\
"[67] 0",\
"[68] 0",\
"[69] 0",\
"[70] 0",\
"[71] 0",\
"[72] 0",\
"[73] 0",\
"[74] 0",\
"[75] 0",\
"[76] 0",\
"[77] 0",\
"[78] 0",\
"[79] 0",\
"[80] 1343",\
"[81] 1332",\
"[82] 1359",\
"[83] 1229",\
"[84] 1266",\
"[85] 1471",\
"[86] 1334",\
"[87] 1334",\
"[88] 1249",\
"[89] 1384",\
"[90] 1400",\
"[91] 1360",\
"[92] 1329",\
"[93] 1380",\
"[94] 1297",\
"[95] 1424",\
"[96] 1272",\
"[97] 1371",\
"[98] 1432",\
"[99] 1546",\
"[100] 1432",\
"[101] 1261",\
"[102] 1446",\
"[103] 1460",\
"[104] 1458",\
"[105] 1467",\
"[106] 1385",\
"[107] 1403",\
"[108] 1392",\
"[109] 1357",\
"[110] 1329",\
"[111] 1449",\
"[112] 1423",\
"[113] 1334",\
"[114] 1324",\
"[115] 1364",\
"[116] 1341",\
"[117] 1444",\
"[118] 1356",\
"[119] 1425",\
"[120] 1302",\
"[121] 1315",\
"[122] 1383",\
"[123] 1239",\
"[124] 1366",\
"[125] 1282",\
"[126] 1261",\
"[127] 1293",\
"[128] 1393",\
"[129] 1354",\
"[130] 1187",\
"[131] 1318",\
"[132] 1236",\
"[133] 1293",\
"[134] 1282",\
"[135] 1404",\
"[136] 1212",\
"[137] 1448",\
"[138] 1304",\
"[139] 1441",\
"[140] 1389",\
"[141] 1388",\
"[142] 1270",\
"[143] 1383",\
"Measured = FLOAT[144] :",\
"[0] 2050",\
"[1] 1782",\
"[2] 1884",\
"[3] 1600",\
"[4] 1457",\
"[5] 1451",\
"[6] 1638",\
"[7] 1618",\
"[8] 1806",\
"[9] 1542",\
"[10] 1813",\
"[11] 1967",\
"[12] 1822",\
"[13] 1763",\
"[14] 1324",\
"[15] 1833",\
"[16] 1726",\
"[17] 1519",\
"[18] 1612",\
"[19] 1556",\
"[20] 1785",\
"[21] 1724",\
"[22] 1518",\
"[23] 1684",\
"[24] 1704",\
"[25] 1751",\
"[26] 1843",\
"[27] 1531",\
"[28] 1356",\
"[29] 1755",\
"[30] 1918",\
"[31] 1914",\
"[32] 1370",\
"[33] 1966",\
"[34] 1407",\
"[35] 1548",\
"[36] 1436",\
"[37] 1376",\
"[38] 1390",\
"[39] 1465",\
"[40] 1902",\
"[41] 1517",\
"[42] 1639",\
"[43] 1706",\
"[44] 2194",\
"[45] 1994",\
"[46] 230",\
"[47] 21",\
"[48] 1454",\
"[49] 1540",\
"[50] 1532",\
"[51] 1362",\
"[52] 1399",\
"[53] 1201",\
"[54] 1336",\
"[55] 1526",\
"[56] 1263",\
"[57] 1358",\
"[58] 1249",\
"[59] 1240",\
"[60] 1278",\
"[61] 1508",\
"[62] 1220",\
"[63] 1400",\
"[64] 0",\
"[65] 0",\
"[66] 0",\
"[67] 0",\
"[68] 0",\
"[69] 0",\
"[70] 0",\
"[71] 0",\
"[72] 0",\
"[73] 0",\
"[74] 0",\
"[75] 0",\
"[76] 0",\
"[77] 0",\
"[78] 0",\
"[79] 0",\
"[80] 1342",\
"[81] 1330",\
"[82] 1357",\
"[83] 1227",\
"[84] 1264",\
"[85] 1470",\
"[86] 1333",\
"[87] 1332",\
"[88] 1247",\
"[89] 1383",\
"[90] 1399",\
"[91] 1360",\
"[92] 1328",\
"[93] 1378",\
"[94] 1296",\
"[95] 1422",\
"[96] 1266",\
"[97] 1365",\
"[98] 1425",\
"[99] 1539",\
"[100] 1425",\
"[101] 1256",\
"[102] 1439",\
"[103] 1454",\
"[104] 1452",\
"[105] 1460",\
"[106] 1379",\
"[107] 1397",\
"[108] 1386",\
"[109] 1351",\
"[110] 1323",\
"[111] 1442",\
"[112] 1422",\
"[113] 1333",\
"[114] 1323",\
"[115] 1363",\
"[116] 1340",\
"[117] 1444",\
"[118] 1355",\
"[119] 1424",\
"[120] 1301",\
"[121] 1314",\
"[122] 1382",\
"[123] 1238",\
"[124] 1365",\
"[125] 1280",\
"[126] 1260",\
"[127] 1292",\
"[128] 1395",\
"[129] 1356",\
"[130] 1188",\
"[131] 1320",\
"[132] 1237",\
"[133] 1294",\
"[134] 1283",\
"[135] 1405",\
"[136] 1213",\
"[137] 1449",\
"[138] 1305",\
"[139] 1443",\
"[140] 1390",\
"[141] 1389",\
"[142] 1271",\
"[143] 1385",\
"Current = FLOAT[144] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"[4] 0",\
"[5] 0",\
"[6] 0",\
"[7] 0",\
"[8] 0",\
"[9] 0",\
"[10] 0",\
"[11] 0",\
"[12] 0",\
"[13] 0",\
"[14] 0",\
"[15] 0",\
"[16] 0",\
"[17] 0",\
"[18] 0",\
"[19] 0",\
"[20] 0",\
"[21] 0",\
"[22] 0",\
"[23] 0",\
"[24] 0",\
"[25] 0",\
"[26] 0",\
"[27] 0",\
"[28] 0",\
"[29] 0",\
"[30] 0",\
"[31] 0",\
"[32] 0",\
"[33] 0",\
"[34] 0",\
"[35] 0",\
"[36] 0",\
"[37] 0",\
"[38] 0",\
"[39] 0",\
"[40] 0",\
"[41] 0",\
"[42] 0",\
"[43] 0",\
"[44] 0",\
"[45] 0",\
"[46] 0",\
"[47] 0",\
"[48] 0",\
"[49] 0",\
"[50] 0",\
"[51] 0",\
"[52] 0",\
"[53] 0",\
"[54] 0",\
"[55] 0",\
"[56] 0",\
"[57] 0",\
"[58] 0",\
"[59] 0",\
"[60] 0",\
"[61] 0",\
"[62] 0",\
"[63] 0",\
"[64] 0",\
"[65] 0",\
"[66] 0",\
"[67] 0",\
"[68] 0",\
"[69] 0",\
"[70] 0",\
"[71] 0",\
"[72] 0",\
"[73] 0",\
"[74] 0",\
"[75] 0",\
"[76] 0",\
"[77] 0",\
"[78] 0",\
"[79] 0",\
"[80] 0",\
"[81] 0",\
"[82] 0",\
"[83] 0",\
"[84] 0",\
"[85] 0",\
"[86] 0",\
"[87] 0",\
"[88] 0",\
"[89] 0",\
"[90] 0",\
"[91] 0",\
"[92] 0",\
"[93] 0",\
"[94] 0",\
"[95] 0",\
"[96] 0",\
"[97] 0",\
"[98] 0",\
"[99] 0",\
"[100] 0",\
"[101] 0",\
"[102] 0",\
"[103] 0",\
"[104] 0",\
"[105] 0",\
"[106] 0",\
"[107] 0",\
"[108] 0",\
"[109] 0",\
"[110] 0",\
"[111] 0",\
"[112] 0",\
"[113] 0",\
"[114] 0",\
"[115] 0",\
"[116] 0",\
"[117] 0",\
"[118] 0",\
"[119] 0",\
"[120] 0",\
"[121] 0",\
"[122] 0",\
"[123] 0",\
"[124] 0",\
"[125] 0",\
"[126] 0",\
"[127] 0",\
"[128] 0",\
"[129] 0",\
"[130] 0",\
"[131] 0",\
"[132] 0",\
"[133] 0",\
"[134] 0",\
"[135] 0",\
"[136] 0",\
"[137] 0",\
"[138] 0",\
"[139] 0",\
"[140] 0",\
"[141] 0",\
"[142] 0",\
"[143] 0",\
"",\
NULL }

typedef struct {
  char      names[144][32];
  float     update_threshold_measured[144];
  float     update_threshold_current[144];
  float     voltage_limit[144];
  float     current_limit[144];
  float     ramping_speed[144];
  struct {
    INT       lrs1440_1;
    INT       lrs1440_2;
  } channels;
  struct {
    struct {
      char      rs232_port[32];
      INT       address;
      INT       polarity[5];
    } lrs1440_1;
    struct {
      char      rs232_port[32];
      INT       address;
      INT       polarity[4];
    } lrs1440_2;
  } devices;
} HV_SETTINGS;

#define HV_SETTINGS_STR(_name) char *_name[] = {\
"[.]",\
"Names = STRING[144] :",\
"[32] CsI%CsI 0",\
"[32] CsI%CsI 1",\
"[32] CsI%CsI 2",\
"[32] CsI%CsI 3",\
"[32] CsI%CsI 4",\
"[32] CsI%CsI 5",\
"[32] CsI%CsI 6",\
"[32] CsI%CsI 7",\
"[32] CsI%CsI 8",\
"[32] CsI%CsI 9",\
"[32] CsI%CsI 10",\
"[32] CsI%CsI 11",\
"[32] CsI%CsI 12",\
"[32] CsI%CsI 13",\
"[32] CsI%CsI 14",\
"[32] CsI%CsI 15",\
"[32] CsI%CsI 16",\
"[32] CsI%CsI 17",\
"[32] CsI%CsI 18",\
"[32] CsI%CsI 19",\
"[32] CsI%CsI 20",\
"[32] CsI%CsI 21",\
"[32] CsI%CsI 22",\
"[32] CsI%CsI 23",\
"[32] CsI%CsI 24",\
"[32] CsI%CsI 25",\
"[32] CsI%CsI 26",\
"[32] CsI%CsI 27",\
"[32] CsI%CsI 28",\
"[32] CsI%CsI 29",\
"[32] CsI%CsI 30",\
"[32] CsI%CsI 31",\
"[32] CsI%CsI 32",\
"[32] CsI%CsI 33",\
"[32] CsI%CsI 34",\
"[32] CsI%CsI 35",\
"[32] CsI%CsI 36",\
"[32] CsI%CsI 37",\
"[32] CsI%CsI 38",\
"[32] CsI%CsI 39",\
"[32] CsI%CsI 40",\
"[32] CsI%CsI 41",\
"[32] CsI%CsI 42",\
"[32] CsI%CsI 43",\
"[32] Beam%B0",\
"[32] Beam%B1",\
"[32] Spare%CH 46",\
"[32] Spare%CH 47",\
"[32] Plastic Veto%PV 0",\
"[32] Plastic Veto%PV 1",\
"[32] Plastic Veto%PV 2",\
"[32] Plastic Veto%PV 3",\
"[32] Plastic Veto%PV 4",\
"[32] Plastic Veto%PV 5",\
"[32] Plastic Veto%PV 6",\
"[32] Plastic Veto%PV 7",\
"[32] Plastic Veto%PV 8",\
"[32] Plastic Veto%PV 9",\
"[32] Plastic Veto%PV 10",\
"[32] Plastic Veto%PV 11",\
"[32] Plastic Veto%PV 12",\
"[32] Plastic Veto%PV 13",\
"[32] Plastic Veto%PV 14",\
"[32] Plastic Veto%PV 15",\
"[32] Target%D0",\
"[32] Target%T0",\
"[32] Target%Veto",\
"[32] Spare%CH 67",\
"[32] Spare%CH 68",\
"[32] Spare%CH 69",\
"[32] Spare%CH 70",\
"[32] Spare%CH 71",\
"[32] Spare%CH 72",\
"[32] Spare%CH 73",\
"[32] Spare%CH 74",\
"[32] Spare%CH 75",\
"[32] Spare%CH 76",\
"[32] Spare%CH 77",\
"[32] Spare%CH 78",\
"[32] Spare%CH 79",\
"[32] NaJ%CH 0",\
"[32] NaJ%CH 1",\
"[32] NaJ%CH 2",\
"[32] NaJ%CH 3",\
"[32] NaJ%CH 4",\
"[32] NaJ%CH 5",\
"[32] NaJ%CH 6",\
"[32] NaJ%CH 7",\
"[32] NaJ%CH 8",\
"[32] NaJ%CH 9",\
"[32] NaJ%CH 10",\
"[32] NaJ%CH 11",\
"[32] NaJ%CH 12",\
"[32] NaJ%CH 13",\
"[32] NaJ%CH 14",\
"[32] NaJ%CH 15",\
"[32] NaJ%CH 16",\
"[32] NaJ%CH 17",\
"[32] NaJ%CH 18",\
"[32] NaJ%CH 19",\
"[32] NaJ%CH 20",\
"[32] NaJ%CH 21",\
"[32] NaJ%CH 22",\
"[32] NaJ%CH 23",\
"[32] NaJ%CH 24",\
"[32] NaJ%CH 25",\
"[32] NaJ%CH 26",\
"[32] NaJ%CH 27",\
"[32] NaJ%CH 28",\
"[32] NaJ%CH 29",\
"[32] NaJ%CH 30",\
"[32] NaJ%CH 31",\
"[32] NaJ%CH 32",\
"[32] NaJ%CH 33",\
"[32] NaJ%CH 34",\
"[32] NaJ%CH 35",\
"[32] NaJ%CH 36",\
"[32] NaJ%CH 37",\
"[32] NaJ%CH 38",\
"[32] NaJ%CH 39",\
"[32] NaJ%CH 40",\
"[32] NaJ%CH 41",\
"[32] NaJ%CH 42",\
"[32] NaJ%CH 43",\
"[32] NaJ%CH 44",\
"[32] NaJ%CH 45",\
"[32] NaJ%CH 46",\
"[32] NaJ%CH 47",\
"[32] NaJ%CH 48",\
"[32] NaJ%CH 49",\
"[32] NaJ%CH 50",\
"[32] NaJ%CH 51",\
"[32] NaJ%CH 52",\
"[32] NaJ%CH 53",\
"[32] NaJ%CH 54",\
"[32] NaJ%CH 55",\
"[32] NaJ%CH 56",\
"[32] NaJ%CH 57",\
"[32] NaJ%CH 58",\
"[32] NaJ%CH 59",\
"[32] NaJ%CH 60",\
"[32] NaJ%CH 61",\
"[32] NaJ%CH 62",\
"[32] NaJ%CH 63",\
"Update Threshold Measured = FLOAT[144] :",\
"[0] 2",\
"[1] 2",\
"[2] 2",\
"[3] 2",\
"[4] 2",\
"[5] 2",\
"[6] 2",\
"[7] 2",\
"[8] 2",\
"[9] 2",\
"[10] 2",\
"[11] 2",\
"[12] 2",\
"[13] 2",\
"[14] 2",\
"[15] 2",\
"[16] 2",\
"[17] 2",\
"[18] 2",\
"[19] 2",\
"[20] 2",\
"[21] 2",\
"[22] 2",\
"[23] 2",\
"[24] 2",\
"[25] 2",\
"[26] 2",\
"[27] 2",\
"[28] 2",\
"[29] 2",\
"[30] 2",\
"[31] 2",\
"[32] 2",\
"[33] 2",\
"[34] 2",\
"[35] 2",\
"[36] 2",\
"[37] 2",\
"[38] 2",\
"[39] 2",\
"[40] 2",\
"[41] 2",\
"[42] 2",\
"[43] 2",\
"[44] 2",\
"[45] 2",\
"[46] 2",\
"[47] 2",\
"[48] 2",\
"[49] 2",\
"[50] 2",\
"[51] 2",\
"[52] 2",\
"[53] 2",\
"[54] 2",\
"[55] 2",\
"[56] 2",\
"[57] 2",\
"[58] 2",\
"[59] 2",\
"[60] 2",\
"[61] 2",\
"[62] 2",\
"[63] 2",\
"[64] 2",\
"[65] 2",\
"[66] 2",\
"[67] 2",\
"[68] 2",\
"[69] 2",\
"[70] 2",\
"[71] 2",\
"[72] 2",\
"[73] 2",\
"[74] 2",\
"[75] 2",\
"[76] 2",\
"[77] 2",\
"[78] 2",\
"[79] 2",\
"[80] 2",\
"[81] 2",\
"[82] 2",\
"[83] 2",\
"[84] 2",\
"[85] 2",\
"[86] 2",\
"[87] 2",\
"[88] 2",\
"[89] 2",\
"[90] 2",\
"[91] 2",\
"[92] 2",\
"[93] 2",\
"[94] 2",\
"[95] 2",\
"[96] 2",\
"[97] 2",\
"[98] 2",\
"[99] 2",\
"[100] 2",\
"[101] 2",\
"[102] 2",\
"[103] 2",\
"[104] 2",\
"[105] 2",\
"[106] 2",\
"[107] 2",\
"[108] 2",\
"[109] 2",\
"[110] 2",\
"[111] 2",\
"[112] 2",\
"[113] 2",\
"[114] 2",\
"[115] 2",\
"[116] 2",\
"[117] 2",\
"[118] 2",\
"[119] 2",\
"[120] 2",\
"[121] 2",\
"[122] 2",\
"[123] 2",\
"[124] 2",\
"[125] 2",\
"[126] 2",\
"[127] 2",\
"[128] 2",\
"[129] 2",\
"[130] 2",\
"[131] 2",\
"[132] 2",\
"[133] 2",\
"[134] 2",\
"[135] 2",\
"[136] 2",\
"[137] 2",\
"[138] 2",\
"[139] 2",\
"[140] 2",\
"[141] 2",\
"[142] 2",\
"[143] 2",\
"Update Threshold Current = FLOAT[144] :",\
"[0] 2",\
"[1] 2",\
"[2] 2",\
"[3] 2",\
"[4] 2",\
"[5] 2",\
"[6] 2",\
"[7] 2",\
"[8] 2",\
"[9] 2",\
"[10] 2",\
"[11] 2",\
"[12] 2",\
"[13] 2",\
"[14] 2",\
"[15] 2",\
"[16] 2",\
"[17] 2",\
"[18] 2",\
"[19] 2",\
"[20] 2",\
"[21] 2",\
"[22] 2",\
"[23] 2",\
"[24] 2",\
"[25] 2",\
"[26] 2",\
"[27] 2",\
"[28] 2",\
"[29] 2",\
"[30] 2",\
"[31] 2",\
"[32] 2",\
"[33] 2",\
"[34] 2",\
"[35] 2",\
"[36] 2",\
"[37] 2",\
"[38] 2",\
"[39] 2",\
"[40] 2",\
"[41] 2",\
"[42] 2",\
"[43] 2",\
"[44] 2",\
"[45] 2",\
"[46] 2",\
"[47] 2",\
"[48] 2",\
"[49] 2",\
"[50] 2",\
"[51] 2",\
"[52] 2",\
"[53] 2",\
"[54] 2",\
"[55] 2",\
"[56] 2",\
"[57] 2",\
"[58] 2",\
"[59] 2",\
"[60] 2",\
"[61] 2",\
"[62] 2",\
"[63] 2",\
"[64] 2",\
"[65] 2",\
"[66] 2",\
"[67] 2",\
"[68] 2",\
"[69] 2",\
"[70] 2",\
"[71] 2",\
"[72] 2",\
"[73] 2",\
"[74] 2",\
"[75] 2",\
"[76] 2",\
"[77] 2",\
"[78] 2",\
"[79] 2",\
"[80] 2",\
"[81] 2",\
"[82] 2",\
"[83] 2",\
"[84] 2",\
"[85] 2",\
"[86] 2",\
"[87] 2",\
"[88] 2",\
"[89] 2",\
"[90] 2",\
"[91] 2",\
"[92] 2",\
"[93] 2",\
"[94] 2",\
"[95] 2",\
"[96] 2",\
"[97] 2",\
"[98] 2",\
"[99] 2",\
"[100] 2",\
"[101] 2",\
"[102] 2",\
"[103] 2",\
"[104] 2",\
"[105] 2",\
"[106] 2",\
"[107] 2",\
"[108] 2",\
"[109] 2",\
"[110] 2",\
"[111] 2",\
"[112] 2",\
"[113] 2",\
"[114] 2",\
"[115] 2",\
"[116] 2",\
"[117] 2",\
"[118] 2",\
"[119] 2",\
"[120] 2",\
"[121] 2",\
"[122] 2",\
"[123] 2",\
"[124] 2",\
"[125] 2",\
"[126] 2",\
"[127] 2",\
"[128] 2",\
"[129] 2",\
"[130] 2",\
"[131] 2",\
"[132] 2",\
"[133] 2",\
"[134] 2",\
"[135] 2",\
"[136] 2",\
"[137] 2",\
"[138] 2",\
"[139] 2",\
"[140] 2",\
"[141] 2",\
"[142] 2",\
"[143] 2",\
"Voltage Limit = FLOAT[144] :",\
"[0] 2500",\
"[1] 2500",\
"[2] 2500",\
"[3] 2500",\
"[4] 2500",\
"[5] 2500",\
"[6] 2500",\
"[7] 2500",\
"[8] 2500",\
"[9] 2500",\
"[10] 2500",\
"[11] 2500",\
"[12] 2500",\
"[13] 2500",\
"[14] 2500",\
"[15] 2500",\
"[16] 2500",\
"[17] 2500",\
"[18] 2500",\
"[19] 2500",\
"[20] 2500",\
"[21] 2500",\
"[22] 2500",\
"[23] 2500",\
"[24] 2500",\
"[25] 2500",\
"[26] 2500",\
"[27] 2500",\
"[28] 2500",\
"[29] 2500",\
"[30] 2500",\
"[31] 2500",\
"[32] 2500",\
"[33] 2500",\
"[34] 2500",\
"[35] 2500",\
"[36] 2500",\
"[37] 2500",\
"[38] 2500",\
"[39] 2500",\
"[40] 2500",\
"[41] 2500",\
"[42] 2500",\
"[43] 2500",\
"[44] 2500",\
"[45] 2500",\
"[46] 2500",\
"[47] 2500",\
"[48] 2500",\
"[49] 2500",\
"[50] 2500",\
"[51] 2500",\
"[52] 2500",\
"[53] 2500",\
"[54] 2500",\
"[55] 2500",\
"[56] 2500",\
"[57] 2500",\
"[58] 2500",\
"[59] 2500",\
"[60] 2500",\
"[61] 2500",\
"[62] 2500",\
"[63] 2500",\
"[64] 1000",\
"[65] 1000",\
"[66] 2200",\
"[67] 2500",\
"[68] 2500",\
"[69] 2500",\
"[70] 2500",\
"[71] 2500",\
"[72] 2500",\
"[73] 2500",\
"[74] 2500",\
"[75] 2500",\
"[76] 2500",\
"[77] 2500",\
"[78] 2500",\
"[79] 2500",\
"[80] 1600",\
"[81] 1600",\
"[82] 1600",\
"[83] 1600",\
"[84] 1600",\
"[85] 1600",\
"[86] 1600",\
"[87] 1600",\
"[88] 1600",\
"[89] 1600",\
"[90] 1600",\
"[91] 1600",\
"[92] 1600",\
"[93] 1600",\
"[94] 1600",\
"[95] 1600",\
"[96] 1600",\
"[97] 1600",\
"[98] 1600",\
"[99] 1600",\
"[100] 1600",\
"[101] 1600",\
"[102] 1600",\
"[103] 1600",\
"[104] 1600",\
"[105] 1600",\
"[106] 1600",\
"[107] 1600",\
"[108] 1600",\
"[109] 1600",\
"[110] 1600",\
"[111] 1600",\
"[112] 1600",\
"[113] 1600",\
"[114] 1600",\
"[115] 1600",\
"[116] 1600",\
"[117] 1600",\
"[118] 1600",\
"[119] 1600",\
"[120] 1600",\
"[121] 1600",\
"[122] 1600",\
"[123] 1600",\
"[124] 1600",\
"[125] 1600",\
"[126] 1600",\
"[127] 1600",\
"[128] 1600",\
"[129] 1600",\
"[130] 1600",\
"[131] 1600",\
"[132] 1600",\
"[133] 1600",\
"[134] 1600",\
"[135] 1600",\
"[136] 1600",\
"[137] 1600",\
"[138] 1600",\
"[139] 1600",\
"[140] 1600",\
"[141] 1600",\
"[142] 1600",\
"[143] 1600",\
"Current Limit = FLOAT[144] :",\
"[0] 3000",\
"[1] 3000",\
"[2] 3000",\
"[3] 3000",\
"[4] 3000",\
"[5] 3000",\
"[6] 3000",\
"[7] 3000",\
"[8] 3000",\
"[9] 3000",\
"[10] 3000",\
"[11] 3000",\
"[12] 3000",\
"[13] 3000",\
"[14] 3000",\
"[15] 3000",\
"[16] 3000",\
"[17] 3000",\
"[18] 3000",\
"[19] 3000",\
"[20] 3000",\
"[21] 3000",\
"[22] 3000",\
"[23] 3000",\
"[24] 3000",\
"[25] 3000",\
"[26] 3000",\
"[27] 3000",\
"[28] 3000",\
"[29] 3000",\
"[30] 3000",\
"[31] 3000",\
"[32] 3000",\
"[33] 3000",\
"[34] 3000",\
"[35] 3000",\
"[36] 3000",\
"[37] 3000",\
"[38] 3000",\
"[39] 3000",\
"[40] 3000",\
"[41] 3000",\
"[42] 3000",\
"[43] 3000",\
"[44] 3000",\
"[45] 3000",\
"[46] 3000",\
"[47] 3000",\
"[48] 3000",\
"[49] 3000",\
"[50] 3000",\
"[51] 3000",\
"[52] 3000",\
"[53] 3000",\
"[54] 3000",\
"[55] 3000",\
"[56] 3000",\
"[57] 3000",\
"[58] 3000",\
"[59] 3000",\
"[60] 3000",\
"[61] 3000",\
"[62] 3000",\
"[63] 3000",\
"[64] 3000",\
"[65] 3000",\
"[66] 3000",\
"[67] 3000",\
"[68] 3000",\
"[69] 3000",\
"[70] 3000",\
"[71] 3000",\
"[72] 3000",\
"[73] 3000",\
"[74] 3000",\
"[75] 3000",\
"[76] 3000",\
"[77] 3000",\
"[78] 3000",\
"[79] 3000",\
"[80] 3000",\
"[81] 3000",\
"[82] 3000",\
"[83] 3000",\
"[84] 3000",\
"[85] 3000",\
"[86] 3000",\
"[87] 3000",\
"[88] 3000",\
"[89] 3000",\
"[90] 3000",\
"[91] 3000",\
"[92] 3000",\
"[93] 3000",\
"[94] 3000",\
"[95] 3000",\
"[96] 3000",\
"[97] 3000",\
"[98] 3000",\
"[99] 3000",\
"[100] 3000",\
"[101] 3000",\
"[102] 3000",\
"[103] 3000",\
"[104] 3000",\
"[105] 3000",\
"[106] 3000",\
"[107] 3000",\
"[108] 3000",\
"[109] 3000",\
"[110] 3000",\
"[111] 3000",\
"[112] 3000",\
"[113] 3000",\
"[114] 3000",\
"[115] 3000",\
"[116] 3000",\
"[117] 3000",\
"[118] 3000",\
"[119] 3000",\
"[120] 3000",\
"[121] 3000",\
"[122] 3000",\
"[123] 3000",\
"[124] 3000",\
"[125] 3000",\
"[126] 3000",\
"[127] 3000",\
"[128] 3000",\
"[129] 3000",\
"[130] 3000",\
"[131] 3000",\
"[132] 3000",\
"[133] 3000",\
"[134] 3000",\
"[135] 3000",\
"[136] 3000",\
"[137] 3000",\
"[138] 3000",\
"[139] 3000",\
"[140] 3000",\
"[141] 3000",\
"[142] 3000",\
"[143] 3000",\
"Ramping Speed = FLOAT[144] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"[4] 0",\
"[5] 0",\
"[6] 0",\
"[7] 0",\
"[8] 0",\
"[9] 0",\
"[10] 0",\
"[11] 0",\
"[12] 0",\
"[13] 0",\
"[14] 0",\
"[15] 0",\
"[16] 0",\
"[17] 0",\
"[18] 0",\
"[19] 0",\
"[20] 0",\
"[21] 0",\
"[22] 0",\
"[23] 0",\
"[24] 0",\
"[25] 0",\
"[26] 0",\
"[27] 0",\
"[28] 0",\
"[29] 0",\
"[30] 0",\
"[31] 0",\
"[32] 0",\
"[33] 0",\
"[34] 0",\
"[35] 0",\
"[36] 0",\
"[37] 0",\
"[38] 0",\
"[39] 0",\
"[40] 0",\
"[41] 0",\
"[42] 0",\
"[43] 0",\
"[44] 0",\
"[45] 0",\
"[46] 0",\
"[47] 0",\
"[48] 0",\
"[49] 0",\
"[50] 0",\
"[51] 0",\
"[52] 0",\
"[53] 0",\
"[54] 0",\
"[55] 0",\
"[56] 0",\
"[57] 0",\
"[58] 0",\
"[59] 0",\
"[60] 0",\
"[61] 0",\
"[62] 0",\
"[63] 0",\
"[64] 0",\
"[65] 0",\
"[66] 0",\
"[67] 0",\
"[68] 0",\
"[69] 0",\
"[70] 0",\
"[71] 0",\
"[72] 0",\
"[73] 0",\
"[74] 0",\
"[75] 0",\
"[76] 0",\
"[77] 0",\
"[78] 0",\
"[79] 0",\
"[80] 0",\
"[81] 0",\
"[82] 0",\
"[83] 0",\
"[84] 0",\
"[85] 0",\
"[86] 0",\
"[87] 0",\
"[88] 0",\
"[89] 0",\
"[90] 0",\
"[91] 0",\
"[92] 0",\
"[93] 0",\
"[94] 0",\
"[95] 0",\
"[96] 0",\
"[97] 0",\
"[98] 0",\
"[99] 0",\
"[100] 0",\
"[101] 0",\
"[102] 0",\
"[103] 0",\
"[104] 0",\
"[105] 0",\
"[106] 0",\
"[107] 0",\
"[108] 0",\
"[109] 0",\
"[110] 0",\
"[111] 0",\
"[112] 0",\
"[113] 0",\
"[114] 0",\
"[115] 0",\
"[116] 0",\
"[117] 0",\
"[118] 0",\
"[119] 0",\
"[120] 0",\
"[121] 0",\
"[122] 0",\
"[123] 0",\
"[124] 0",\
"[125] 0",\
"[126] 0",\
"[127] 0",\
"[128] 0",\
"[129] 0",\
"[130] 0",\
"[131] 0",\
"[132] 0",\
"[133] 0",\
"[134] 0",\
"[135] 0",\
"[136] 0",\
"[137] 0",\
"[138] 0",\
"[139] 0",\
"[140] 0",\
"[141] 0",\
"[142] 0",\
"[143] 0",\
"",\
"[Channels]",\
"LRS1440 1 = INT : 80",\
"LRS1440 2 = INT : 64",\
"",\
"[Devices/LRS1440 1]",\
"RS232 Port = STRING : [32] COM1",\
"Address = INT : 1",\
"Polarity = INT[5] :",\
"[0] -1",\
"[1] -1",\
"[2] -1",\
"[3] -1",\
"[4] -1",\
"",\
"[Devices/LRS1440 2]",\
"RS232 Port = STRING : [32] COM1",\
"Address = INT : 2",\
"Polarity = INT[4] :",\
"[0] -1",\
"[1] -1",\
"[2] -1",\
"[3] -1",\
"",\
NULL }

#endif

#ifndef EXCL_TEMPERATURE

typedef struct {
  float     input[11];
  float     output[2];
} TEMPERATURE_EVENT;

#define TEMPERATURE_EVENT_STR(_name) char *_name[] = {\
"[.]",\
"Input = FLOAT[11] :",\
"[0] 15.08",\
"[1] 13.74",\
"[2] 14.24",\
"[3] 15.35",\
"[4] 14.21",\
"[5] 19.23",\
"[6] 15.5",\
"[7] 27.2461",\
"[8] 49.6094",\
"[9] 15.4297",\
"[10] 47.6563",\
"Output = FLOAT[2] :",\
"[0] 0",\
"[1] 0",\
"",\
NULL }

typedef struct {
  char      names_input[11][32];
  char      names_output[2][32];
  float     update_threshold[11];
  float     input_offset[11];
  float     output_offset[2];
  float     input_factor[11];
  float     output_factor[2];
  struct {
    INT       dastemp;
    INT       das_1600_ai;
    INT       das_1600_ao;
  } channels;
  struct {
    struct {
      WORD      io_base;
    } dastemp;
    struct {
      WORD      io_base;
      WORD      gain[16];
    } das_1600_ai;
    struct {
      WORD      io_base;
      WORD      gain[16];
    } das_1600_ao;
  } devices;
} TEMPERATURE_SETTINGS;

#define TEMPERATURE_SETTINGS_STR(_name) char *_name[] = {\
"[.]",\
"Names Input = STRING[11] :",\
"[32] Temp. 1",\
"[32] Temp. 2",\
"[32] Temp. 3",\
"[32] Temp. 4",\
"[32] Temp. 5",\
"[32] Temp. 6",\
"[32] Temp. 7",\
"[32] Hum. Temp. 1",\
"[32] Humidity 1",\
"[32] Hum. Temp. 2",\
"[32] Humidity 2",\
"Names Output = STRING[2] :",\
"[32] Output Channel 0",\
"[32] Output Channel 1",\
"Update Threshold = FLOAT[11] :",\
"[0] 0.1",\
"[1] 0.1",\
"[2] 0.1",\
"[3] 0.1",\
"[4] 0.1",\
"[5] 0.1",\
"[6] 0.1",\
"[7] 0.1",\
"[8] 0.1",\
"[9] 0.1",\
"[10] 0.1",\
"Input Offset = FLOAT[11] :",\
"[0] 0",\
"[1] 0",\
"[2] 0",\
"[3] 0",\
"[4] 0",\
"[5] 0",\
"[6] 0",\
"[7] 0",\
"[8] 0",\
"[9] 0",\
"[10] 0",\
"Output Offset = FLOAT[2] :",\
"[0] 0",\
"[1] 0",\
"Input Factor = FLOAT[11] :",\
"[0] 1",\
"[1] 1",\
"[2] 1",\
"[3] 1",\
"[4] 1",\
"[5] 1",\
"[6] 1",\
"[7] 10",\
"[8] 10",\
"[9] 10",\
"[10] 10",\
"Output Factor = FLOAT[2] :",\
"[0] 1",\
"[1] 1",\
"",\
"[Channels]",\
"DASTEMP = INT : 7",\
"DAS-1600 AI = INT : 4",\
"DAS-1600 AO = INT : 2",\
"",\
"[Devices/DASTEMP]",\
"IO Base = WORD : 544",\
"",\
"[Devices/DAS-1600 AI]",\
"IO Base = WORD : 544",\
"Gain = WORD[16] :",\
"[0] 1",\
"[1] 1",\
"[2] 1",\
"[3] 1",\
"[4] 1",\
"[5] 1",\
"[6] 1",\
"[7] 1",\
"[8] 1",\
"[9] 1",\
"[10] 1",\
"[11] 1",\
"[12] 1",\
"[13] 1",\
"[14] 1",\
"[15] 1",\
"",\
"[Devices/DAS-1600 AO]",\
"IO Base = WORD : 576",\
"Gain = WORD[16] :",\
"[0] 1",\
"[1] 1",\
"[2] 1",\
"[3] 1",\
"[4] 1",\
"[5] 1",\
"[6] 1",\
"[7] 1",\
"[8] 1",\
"[9] 1",\
"[10] 1",\
"[11] 1",\
"[12] 1",\
"[13] 1",\
"[14] 1",\
"[15] 1",\
"",\
NULL }

#endif

