/********************************************************************\

  Name:         gainmatch.c
  Created by:   Stefan Ritt

  Contents:     Program to match gains of CsI ADC spectra


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  15-JUL-95    SR    created


\********************************************************************/

#include <stdio.h>
#include <math.h>

/* midas includes */
#include "midas.h"
#include "msystem.h"
#include "util.h"

/* cernlib includes */
#ifdef OS_WINNT
#define VISUAL_CPLUSPLUS
#endif

#ifdef __linux__
#define f2cFortran
#endif

#include <cfortran.h>
#include <hbook.h>

/* paw common memory */
#define PAWC_SIZE 1000000

#ifdef extname
int pawc_[PAWC_SIZE];
#else
int PAWC[PAWC_SIZE];
#endif

#define SUM_N_BINS        500
#define SUM_X_LOW           0
#define SUM_X_HIGH       4000

double tgt_loss[] = {
4.0, 4.0, 4.0, 4.0, 4.0, 4.0, 4.0, 4.0, 4.0, 4.2,
4.2, 4.2, 4.2, 4.2, 4.2, 4.2, 4.2, 4.2, 4.2, 4.6,
4.7, 4.7, 4.6, 4.5, 4.6, 4.7, 4.7, 4.6, 5.5, 5.6,
5.5, 5.1, 5.5, 5.6, 5.5, 6.6, 6.6, 6.1, 6.6, 6.6,
6.4, 6.4, 6.4, 6.4
};

/* hv_index[NaI ADC index (0..63)] gives HV channel index */
int hv_index[]={
   89, 90, 91, 92, 93, 94,
   97, 98, 99,100,101,102,
  105,106,107,108,109,110,
  113,114,115,116,117,118,
  121,122,123,124,125,126,
  129,130,131,132,133,134,
   80, 81, 82, 83, 84, 85,
   86, 87, 88, 95, 96,103,
  104,111,112,119,120,127,
  128,135,136,137,138,139,
  140,141,142,143
};

float mid_point = 51.3f;

#define RANGE_LOW  0.9
#define RANGE_HIGH 1.2

#define MODE_NAI          1
#define MODE_CSI_SINGLE   2
#define MODE_CSI_MULTI    3

/*------------------------------------------------------------------*/

main()
{
int   status, i, j, lrec, istat, size, i_low, i_high;
float hist_adc[SUM_N_BINS], hist_ref[SUM_N_BINS];
float gain[200], gain_error[200], old_gain[200];
float old_hv[200], new_hv[200];
HNDLE hDB, hkey;
int   histo_id, ref_id, n_histo, channel_offset, mode;
float roi_low, roi_high, noent[200], maxent;
BOOL  tgt_corr;
time_t now;
FILE  *f;
BOOL  clear, set_hv;
char  str[80];

  printf("Match NaI (n), CsI two arm TRIG=1 (2) or CsI single arm TRIG=64 (1): \n");
  scanf("%c", &i);
  mode = MODE_NAI;
  if ((char) i == '2')
    mode = MODE_CSI_MULTI;
  if ((char) i == '1')
    mode = MODE_CSI_SINGLE;

//  printf("Enter ID of reference histo in REFHISTOS.RZ: \n");
//  scanf("%d", &ref_id);
  if (mode == MODE_NAI)
    ref_id = 11000;
  else if (mode == MODE_CSI_SINGLE)
    ref_id = 12000;
  else
    ref_id = 3000;

//  printf("Enter ID of first histo to match: \n");
//  scanf("%d", &histo_id);
  if (mode == MODE_NAI)
    channel_offset = 80;
  else
    channel_offset = 0;
  histo_id = 3000+channel_offset;

//  printf("Enter number of histos to match: \n");
//  scanf("%d", &n_histo);
  if (mode == MODE_NAI)
//    n_histo = 64;
    n_histo = 36; // no vetos
  else
    n_histo = 40;

//  printf("Enter feature region Xlow Xhigh: \n");
//  scanf("%f %f", &roi_low, &roi_high);
  if (mode == MODE_NAI)
    {
    roi_low = 750.f; 
    roi_high = 2500.f;
    }
  else if (mode == MODE_CSI_MULTI)
    {
    roi_low = 800.f;
    roi_high = 2200.f;
    }
  else if (mode == MODE_CSI_SINGLE)
    {
    roi_low = 2500.f;
    roi_high = 3500.f;
    }

  i_low  = (int) ((roi_low-SUM_X_LOW)/(SUM_X_HIGH-SUM_X_LOW)*SUM_N_BINS);
  i_high = (int) ((roi_high-SUM_X_LOW)/(SUM_X_HIGH-SUM_X_LOW)*SUM_N_BINS);

//  printf("Perform target correction ? (0/1): \n");
//  scanf("%d", &tgt_corr);
  tgt_corr = 0;

  /* now connect to server */
  status = cm_connect_experiment("", "", "Gain Match", 0);
  if (status != CM_SUCCESS)
    {
    printf("Cannot connect to experiment\n");
    return 0;
    }
          
  cm_set_watchdog_params(0, 0);

  /* get old software gains */
  cm_get_experiment_database(&hDB, NULL);
  db_find_key(hDB, 0, "/Analyzer/Parameters/ADC calibration/Software Gain", &hkey);
  size = sizeof(float);
  for (i=0 ; i<n_histo ; i++)
    db_get_data_index(hDB, hkey, &old_gain[i], &size, channel_offset + i, TID_FLOAT);

  /* and HVs */
  db_find_key(hDB, 0, "/Equipment/HV/Variables/Demand", &hkey);
  for (i=0 ; i<n_histo ; i++)
    if (mode == MODE_NAI)
      db_get_data_index(hDB, hkey, &old_hv[i], &size, hv_index[i], TID_FLOAT);
    else
      db_get_data_index(hDB, hkey, &old_hv[i], &size, i, TID_FLOAT);

  /* init PAW local memory */
  HLIMIT(PAWC_SIZE);

  /* read reference histo */
  lrec = 1024;
  if (mode != MODE_CSI_MULTI)
    HROPEN(1, "REF", "refhistos.rz", " ", lrec, istat);
  else
    {
    printf("Enter run number for reference histos:\n");
    scanf("%d", &i);
    sprintf(str, "e:\\his%05d.rz", i);
    HROPEN(1, "REF", str, " ", lrec, istat);
    }

  if (istat != 0)
    {
    printf("Cannot open refhistos.rz\n");
    cm_disconnect_experiment();
    return 1;
    }

  /* get single reference histo */
  if (mode != MODE_CSI_MULTI)
    {
    HRIN(ref_id, 9999, 0);
    if (HEXIST(ref_id))
      HUNPAK(ref_id, hist_ref[0], "HIST", 1);
    else
      {
      printf("No histo with ID %d found in file REFHISTOS.RZ\n", ref_id);
      cm_disconnect_experiment();
      return 1;
      }
    }
  
  /* map to PAW shared memory */
  HLIMAP(0, "ONLN");

  /* find histo with max statistics */
  for (i=0,maxent=0.f ; i < n_histo ; i++)
    {
    HRIN(histo_id+i, 9999, 0);
    HUNPAK(histo_id+i, hist_adc[0], "HIST", 1);
    for (j=i_low,noent[i]=0.f ; j<i_high; j++)
      noent[i] += hist_adc[j];
    if (noent[i] > maxent)
      maxent = noent[i];
    }

  /* loop over histos */
  for (i = 0 ; i < n_histo ; i++)
    {
    /* get individual reference histo */
    if (mode == MODE_CSI_MULTI)
      {
      HCDIR("//REF", " ");
      if (HEXIST(ref_id+i))
        HDELET(ref_id+i);
      HRIN(ref_id+i, 9999, 0);
      HUNPAK(ref_id+i, hist_ref[0], "HIST", 1);
      }

    /* get ADC histo */
    HCDIR("//ONLN", " ");
    if (HEXIST(histo_id+i))
      HDELET(histo_id+i);

    HRIN(histo_id+i, 9999, 0);
    HUNPAK(histo_id+i, hist_adc[0], "HIST", 1);

    printf("Histo %4d: %6.0f entries, ", histo_id+i, noent[i]);

    /* check if enough statistics */
//    if (noent[i] > maxent/10)
    if (noent[i] > 100)
      {
      gain_match(hist_ref, hist_adc, SUM_N_BINS,
                 (float)SUM_X_LOW, (float)SUM_X_HIGH,
                 roi_low, roi_high, (float)RANGE_LOW, (float)RANGE_HIGH,
                 &gain[i], &gain_error[i]);

      /* multiply to old gain */
      gain[i] *= old_gain[i];

      /* apply target correction */
      if (tgt_corr)
        {
        gain[i] /= mid_point / (mid_point - (float) tgt_loss[i]);

        /* apply correction for shifted reference histo */
        gain[i] *= 1.1f;
        }

      /* calculate HV correction for 10-stage PMTs */
      new_hv[i] = old_hv[i] * (float) pow((double) gain[i], 0.1);

      /* round HV */
      new_hv[i] = (float) ((int) (new_hv[i]+0.5f));

      printf("%1.3f +- %1.3f, HV %4.0fV %+1.0fV",
        gain[i], gain_error[i], old_hv[i], new_hv[i]-old_hv[i]);

      if (mode == MODE_NAI)
        printf("  HV channel:%d",hv_index[i]-80);
    
      if (abs(gain[i]-1)>gain_error[i] && abs(new_hv[i]-old_hv[i])>=2)
        printf(" *");
      printf("\n");
      }
    else
      {
      gain[i] = old_gain[i];
      new_hv[i] = old_hv[i];
      printf("not enough statistics in ROI\n");
      }
    }

/*
  printf("Write software gains to ODB? y/[n] ");
  i = getch();
  set_gain = (i == 'y');
  printf("\n");
  if (set_gain)
    {
    db_find_key(hDB, 0, "/Analyzer/Parameters/ADC calibration/Software Gain", &hkey);
    for (i=0 ; i<n_histo ; i++)
      db_set_data_index(hDB, hkey, &gain[i], sizeof(float), channel_offset+i, TID_FLOAT);
    db_find_key(hDB, 0, "/Analyzer/Parameters/ADC calibration/Software Gain Errors", &hkey);
    for (i=0 ; i<n_histo ; i++)
      db_set_data_index(hDB, hkey, &gain_error[i], sizeof(float), channel_offset+i, TID_FLOAT);
    }
*/
  printf("Apply HV changes? y/[n] ");
  i = getch();
  set_hv = (i == 'y');
  printf("\n");
  if (set_hv)
    {
    db_find_key(hDB, 0, "/Equipment/HV/Variables/Demand", &hkey);
    for (i=0 ; i<n_histo ; i++)
      if (mode == MODE_NAI)
        db_set_data_index(hDB, hkey, &new_hv[i], sizeof(float), hv_index[i], TID_FLOAT);
      else
        db_set_data_index(hDB, hkey, &new_hv[i], sizeof(float), i, TID_FLOAT);

    /* reset software gain */
    gain[0] = 1.f;
    gain_error[0] = 0.f;
    db_find_key(hDB, 0, "/Analyzer/Parameters/ADC calibration/Software Gain", &hkey);
    for (i=0 ; i<n_histo ; i++)
      db_set_data_index(hDB, hkey, &gain[0], sizeof(float), channel_offset+i, TID_FLOAT);
    db_find_key(hDB, 0, "/Analyzer/Parameters/ADC calibration/Software Gain Errors", &hkey);
    for (i=0 ; i<n_histo ; i++)
      db_set_data_index(hDB, hkey, &gain_error[0], sizeof(float), channel_offset+i, TID_FLOAT);
    }

  printf("Clear histos? y/[n] ");
  i = getch();
  clear = (i == 'y');
  printf("\n");
  if (clear)
    {
    if (cm_connect_client("analyzer", &i) == CM_SUCCESS)
      {
      rpc_call(i, RPC_ANA_CLEAR_HISTOS, 0, 0);
      cm_disconnect_client(i, FALSE);
      }
    }
  
  cm_disconnect_experiment();

  printf("Print values? y/[n] ");
  i = getch();
  printf("\n");
  if (i == 'y')
    {
    /* write resutls to file */
    f = fopen("c:\\online\\gainmatch.txt", "w");

    time(&now);
    fprintf(f, "%s\n", ctime(&now));

    if (mode == MODE_CSI_MULTI)
      fprintf(f, "Reference histos: %s\n\n", str);

    for (i = 0 ; i < n_histo ; i++)
      {
      if (noent[i] > 500)
        {
        fprintf(f, "Histo %02d: %6.0f entries, ", histo_id+i, noent[i]);
        fprintf(f, "%1.3f +- %1.3f, HV %4.0fV %+1.0fV",
          gain[i], gain_error[i], old_hv[i], 
          new_hv[i]-old_hv[i]);

        if (mode == MODE_NAI)
          fprintf(f, "  HV channel:%d", hv_index[i]-80);

        if (abs(gain[i]-1)>gain_error[i] && abs(new_hv[i]-old_hv[i])>=2)
          fprintf(f, " *");
        fprintf(f, "\n");
        }
      }

  //  fprintf(f, "\nSoftware gains have been %s\n", set_gain ? "applied" : "not applied");
    fprintf(f, "\nHV changes have been %s\n", set_hv ? "applied" : "not applied");
    fprintf(f, "Histos have been %s\n", clear ? "cleared" : "not cleared");

    fclose(f);

    system("start notepad c:\\online\\gainmatch.txt");
    }

  return 1;
}
