/********************************************************************\

  Name:         mfeuser.c
  Created by:   Stefan Ritt

  Contents:     Experiment specific readout code (user part) of
                Midas frontend


  Revision history
  ------------------------------------------------------------------
  date         by    modification
  ---------    ---   ------------------------------------------------
  25-JAN-95    SR    created


\********************************************************************/

#include <stdio.h>
#include <io.h>
#include "midas.h"
#include "cd_hv.h"
#include "cd_multi.h"

/*-- Globals -------------------------------------------------------*/

/* The frontend name (client name) as seen by other MIDAS clients   */
char *frontend_name = "SC Frontend";

/* frontend_loop is called periodically if this variable is TRUE    */
BOOL frontend_call_loop = FALSE;

/* a frontend status page is displayed with this frequency in ms    */
INT display_period = 1000;

/*-- Equipment list ------------------------------------------------*/

/* device driver list */
DEVICE_DRIVER hv_driver[] = {
  { "LRS1440 1", lrs1440, 80 },
//  { "LRS1440 2", lrs1440, 64 },
  { "" }
};

DEVICE_DRIVER multi_driver[] = {
//  { "NULL I",  null, 2, CH_INPUT },
//  { "NULL O",  null, 2, CH_OUTPUT },
  { "DASTEMP",  dastemp, 7, CH_INPUT },        /* temperature input */
  { "DAS-1600 AI", das1600_ai, 4, CH_INPUT },  /* 4 analog input channels */
  { "DAS-1600 AO", das1600_ao, 2, CH_OUTPUT }, /* 2 analog output channels */
  { "" }
};


EQUIPMENT equipment[] = {

  { "HV",                 /* equipment name */
    3, 0,                 /* event ID, trigger mask */
    "SYSTEM",             /* event buffer */
    EQ_SLOW,              /* equipment type */
    "FIXED",              /* format */
    TRUE,                 /* enabled */
    RO_RUNNING |
    RO_TRANSITIONS,       /* read when running and on transitions */
    60000,                /* read every 60 sec */
    0,                    /* stop run after this event limit */
    1,                    /* log history every event */
    "", "", 
    cd_hv_read,           /* readout routine */
    cd_hv,                /* class driver main routine */
    NULL,                 /* init string */
    hv_driver,            /* device driver list */
  },

  { "Temperature",        /* equipment name */
    4, 0,                 /* event ID, trigger mask */
    "SYSTEM",             /* event buffer */
    EQ_SLOW,              /* equipment type */
    "FIXED",              /* format */
    TRUE,                 /* enabled */
    RO_RUNNING |
    RO_TRANSITIONS,       /* read when running and on transitions */
    60000,                /* read every 60 sec */
    0,                    /* stop run after this event limit */
    1,                    /* log history every event */
    "", "", 
    cd_multi_read,        /* readout routine */
    cd_multi,             /* class driver main routine */
    NULL,                 /* init string */
    multi_driver,         /* device driver list */
  },

  { "" }
};


/*-- Frontend Init -------------------------------------------------*/

INT frontend_init()
{
  return CM_SUCCESS;
}

/*-- Frontend Exit -------------------------------------------------*/

INT frontend_exit()
{
  return CM_SUCCESS;
}

/*-- Frontend Loop -------------------------------------------------*/

INT frontend_loop()
{
  return CM_SUCCESS;
}

/*-- Begin of Run --------------------------------------------------*/

INT begin_of_run(INT run_number, char *error)
{
  return CM_SUCCESS;
}

/*-- End of Run ----------------------------------------------------*/

INT end_of_run(INT run_number, char *error)
{
  return CM_SUCCESS;
}

/*-- Pause Run -----------------------------------------------------*/

INT pause_run(INT run_number, char *error)
{
  return CM_SUCCESS;
}

/*-- Resuem Run ----------------------------------------------------*/

INT resume_run(INT run_number, char *error)
{
  return CM_SUCCESS;
}

/*------------------------------------------------------------------*/
