/*********************************************************************

  Name:         pcos.c
  Created by:   Stefan Ritt

  Cotents:      Routines for reading LeCroy PCOS III system
                

  Revision history
  ------------------------------------------------------------------
  date        by    modification
  ---------   ---   ------------------------------------------------
  27-JUN-97   SR    created

*********************************************************************/

#include <stdio.h>
#include <stdlib.h>

#include "midas.h"

#define EXCL_HV
#define EXCL_ADC_CALIBRATION
#include "..\event.h"

#define CAMAC_BASE_DEFINED
#define BYTE_DEFINED
#include "hyt1331.h"
#include "pcos.h"

extern TRIGGER_SETTINGS trigger_settings;

/*------------------------------------------------------------------*/

BOOL pcos_init(int camac_slot)
{
int   i, n, last_plane, wire_order;
WORD  q, x;
WORD  log_addr, contr_addr;
BYTE  idel, ithres;

  /**** init DBI ****/
  CAMOQ(camac_slot, 0, 9, 0, &q, &x);
  if (!q || !x)
    {
    cm_msg(MERROR, "pcos_init", "Error accessing DBI at slot %d", camac_slot);
    return FALSE;
    }

  n = sizeof(trigger_settings.pcos.slot) / sizeof(WORD);

  last_plane = -1;

  for(i = 0; i < n; i++)
    {
    idel   = (BYTE) min(255, (trigger_settings.pcos.delay[i] - 300) / 1.5);
    ithres = (BYTE) min(255, trigger_settings.pcos.threshold[i]/0.06);

    contr_addr = (1 << 10);

    /**** set logical address as combination of plane and wire order ****/
    log_addr = trigger_settings.pcos.plane[i] << 4;
    if (trigger_settings.pcos.plane[i] != last_plane)
      {
      last_plane = trigger_settings.pcos.plane[i];
      wire_order = 0;
      }
    else
      wire_order++;
    log_addr |= wire_order;
    log_addr &= 0x1FF;

    CAMO(camac_slot, 0, 16, contr_addr | (1<<3) | (1<<1));
    CAMO(camac_slot, 0, 16, (1<<15) | log_addr);
    CAMO(camac_slot, 0, 16, (1<<15) | (trigger_settings.pcos.slot[i]<<3) |
                                    (log_addr>>8));

    /**** set delay ****/
    CAMO(camac_slot, 0, 16, contr_addr | (1<<3) | (1<<2));
    CAMO(camac_slot, 0, 16, (1<<15) | idel);
    CAMO(camac_slot, 0, 16, (1<<15) | (trigger_settings.pcos.slot[i]<<3));

    /**** set threshold ****/
    CAMO(camac_slot, 0, 16, contr_addr | (1<<3) | (1<<2));
    CAMO(camac_slot, 0, 16, (1<<15) | ithres);
    CAMO(camac_slot, 0, 16, (1<<15) | (trigger_settings.pcos.slot[i]<<3) | 1);
    }

  /**** no inhibit any more ****/
  CAMO(camac_slot, 0, 16, contr_addr);

  return TRUE;
}

/*------------------------------------------------------------------*/

int pcos_read(int camac_slot, WORD *data)
{
WORD i, d, n;

  /**** init memory counter ****/
  CAMO8(camac_slot, 1, 11, 0);

  /**** read back data from memory ****/
  CAMI(camac_slot, 0, 2, &d);
  n = d & 0xFFF;

  /**** limit datasize ****/
  if (n > 20)
    n = 20;

  /**** read out data words ****/
  for (i=0 ; i < n-1 ; i++)
    {
    CAMI(camac_slot, 0, 2, &d);
    *data++ = d;

    if ((d & 0xC000) == 0xC000)
      break; //delimiter found
    }

  /**** clear LeCroy 4299 ****/
  CAMO(camac_slot, 0, 11, 0);

  return n-1;
}
